# ozi-spec CHANGELOG
## 1.1.12 (2025-11-12)


### Bug fixes


* fix: Update Python version matrix in ozi.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`1d8fa97`](https://github.com/OZI-Project/ozi-spec/commit/1d8fa971600815fe56e9b024a88ce5f1396d76fa))

* fix: manually set OZI supported python versions (#544)
([`d073a06`](https://github.com/OZI-Project/ozi-spec/commit/d073a06239eac8928b47c60ca2555aeaa39774d2))

* fix: manually set OZI supported python versions — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`d073a06`](https://github.com/OZI-Project/ozi-spec/commit/d073a06239eac8928b47c60ca2555aeaa39774d2))

* fix: fix mypy complaints — Eden Ross Duff MSc <rjdbcm@outlook.com>

 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`d073a06`](https://github.com/OZI-Project/ozi-spec/commit/d073a06239eac8928b47c60ca2555aeaa39774d2))


### Build system


* build(deps): bump actions/dependency-review-action from 4.8.1 to 4.8.2

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.8.1 to 4.8.2.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/40c09b7dc99638e5ddb0bfd91c1673effc064d8a...3c4e3dcb1aa7874d2c16be7d79418e9b7efd6261)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-version: 4.8.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`db60075`](https://github.com/OZI-Project/ozi-spec/commit/db60075fd201727a5a14f2c1968b8e907a8c0914))

* build(deps): bump step-security/harden-runner from 2.13.1 to 2.13.2

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.13.1 to 2.13.2.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/f4a75cfd619ee5ce8d5b864b0d183aff3c69b55a...95d9a5deda9de15063e7595e9719c11c38c90ae2)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-version: 2.13.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`974a85f`](https://github.com/OZI-Project/ozi-spec/commit/974a85fb6766ab26e8a8290d84ee37ff8eac305c))

* build(deps): bump actions/upload-artifact from 4.6.2 to 5.0.0

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.6.2 to 5.0.0.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/ea165f8d65b6e75b540449e92b4886f43607fa02...330a01c490aca151604b8cf639adc76d48f6c5d4)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-version: 5.0.0
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`effa8bf`](https://github.com/OZI-Project/ozi-spec/commit/effa8bf9446a968385cf9cf3abbb1f3b0e384b35))

## 1.1.11 (2025-10-23)


### Build system


* build(deps): bump github/codeql-action from 4.30.9 to 4.31.2

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 4.30.9 to 4.31.2.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/16140ae1a102900babc80a33c44059580f687047...0499de31b99561a6d14a36a5f662c2a54f91beee)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 4.31.2
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`458f89b`](https://github.com/OZI-Project/ozi-spec/commit/458f89b1df93ffeccf47e3809dd754d914a3885b))

* build: Update Meson version constraint in pyproject.toml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`c6439bf`](https://github.com/OZI-Project/ozi-spec/commit/c6439bfba7d726e36e38d7bae4f0dc5a6b3ffb70))

## 1.1.10 (2025-10-22)


### Build system


* build(deps): bump github/codeql-action from 3.30.5 to 4.30.9

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.30.5 to 4.30.9.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/3599b3baa15b485a2e49ef411a7a4bb2452e7f93...16140ae1a102900babc80a33c44059580f687047)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 4.30.9
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`9249193`](https://github.com/OZI-Project/ozi-spec/commit/924919378eb6391e33c249f869800b6cfe586d6f))

* build(deps): bump actions/dependency-review-action from 4.8.0 to 4.8.1

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.8.0 to 4.8.1.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/56339e523c0409420f6c2c9a2f4292bbb3c07dd3...40c09b7dc99638e5ddb0bfd91c1673effc064d8a)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-version: 4.8.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`189750c`](https://github.com/OZI-Project/ozi-spec/commit/189750cdb1c6255330fd6e265fca6cf91f273ffd))

* build: Update Python version check in test_metadata — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`44a25b3`](https://github.com/OZI-Project/ozi-spec/commit/44a25b34edc978a7ddc7971f5c0fc22c0b3de33d))

* build(deps): bump the ozi group with 2 updates

Bumps the ozi group with 2 updates: [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) and [OZI-Project/release](https://github.com/ozi-project/release).


Updates `OZI-Project/checkpoint` from 1.10.1 to 1.11.0
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/b8935c41223bccd7886bd6a2f668b12a23859ed7...5c04e23edea0edcd1eb731ad465d3fb7fe5ad0d7)

Updates `OZI-Project/release` from 1.10.0 to 1.11.0
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/60a6112177f9e232a55f0d2dfe3aa0d2da322cf1...14ba53970650ad2d5c8ac8c335074155c78cccec)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.11.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
  dependency-group: ozi
- dependency-name: OZI-Project/release
  dependency-version: 1.11.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
  dependency-group: ozi
... — dependabot[bot] <support@github.com>
([`6315350`](https://github.com/OZI-Project/ozi-spec/commit/6315350b1850f83093d90fd652df055d654f4e6e))

## 1.1.9 (2025-10-02)


### Build system


* build(deps): bump github/codeql-action from 3.30.2 to 3.30.5

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.30.2 to 3.30.5.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/d3678e237b9c32a6c9bffb3315c335f976f3549f...3599b3baa15b485a2e49ef411a7a4bb2452e7f93)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.30.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`fad405d`](https://github.com/OZI-Project/ozi-spec/commit/fad405dcedaba5ae0988a66bc61af11d98438472))

* build(deps): bump actions/dependency-review-action from 4.7.3 to 4.8.0

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.7.3 to 4.8.0.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/595b5aeba73380359d98a5e087f648dbb0edce1b...56339e523c0409420f6c2c9a2f4292bbb3c07dd3)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-version: 4.8.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`f5c2858`](https://github.com/OZI-Project/ozi-spec/commit/f5c28582f0c975c8ddb1dad904cdd744c16ed4d9))

* build(deps): bump the ozi group across 1 directory with 4 updates

Bumps the ozi group with 4 updates in the / directory: [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint), [OZI-Project/draft](https://github.com/ozi-project/draft), [OZI-Project/provenance](https://github.com/ozi-project/provenance) and [OZI-Project/publish](https://github.com/ozi-project/publish).


Updates `OZI-Project/checkpoint` from 1.10.0 to 1.10.1
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1faf4433bbcc31ed6a0104896a92564d94182b20...b8935c41223bccd7886bd6a2f668b12a23859ed7)

Updates `OZI-Project/draft` from 1.17.3 to 1.17.4
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/3df8701fb8fbda746814804dcdc1b6e7533d4fe8...d1cca28d3fa7f004b7b21abcb945e6760246bae7)

Updates `OZI-Project/provenance` from 1.0.0 to 1.1.0
- [Release notes](https://github.com/ozi-project/provenance/releases)
- [Commits](https://github.com/ozi-project/provenance/compare/9a0953f8937c2d16844fcf5f79f6295058bebbd3...96f6b35116d8140aaa0415fe31dddc4a4a84af2d)

Updates `OZI-Project/publish` from 1.17.3 to 1.17.4
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/c3ea682a04a1458e0edc4886979850a647304677...4ec8a034b233d85270e2b80ab567b1691f708b02)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.10.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
  dependency-group: ozi
- dependency-name: OZI-Project/draft
  dependency-version: 1.17.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
  dependency-group: ozi
- dependency-name: OZI-Project/provenance
  dependency-version: 1.1.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
  dependency-group: ozi
- dependency-name: OZI-Project/publish
  dependency-version: 1.17.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
  dependency-group: ozi
... — dependabot[bot] <support@github.com>
([`c863adf`](https://github.com/OZI-Project/ozi-spec/commit/c863adf0c4716353e7c78e15a1da29080740c9d8))

## 1.1.8 (2025-09-09)


### Build system


* build(deps): bump ossf/scorecard-action from 2.4.2 to 2.4.3

Bumps [ossf/scorecard-action](https://github.com/ossf/scorecard-action) from 2.4.2 to 2.4.3.
- [Release notes](https://github.com/ossf/scorecard-action/releases)
- [Changelog](https://github.com/ossf/scorecard-action/blob/main/RELEASE.md)
- [Commits](https://github.com/ossf/scorecard-action/compare/05b42c624433fc40578a4040d5cf5e36ddca8cde...4eaacf0543bb3f2c246792bd56e8cdeffafb205a)


updated-dependencies:
- dependency-name: ossf/scorecard-action
  dependency-version: 2.4.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`02ee5ef`](https://github.com/OZI-Project/ozi-spec/commit/02ee5ef1c3050274efff224e4b0763a08d71009a))

* build(deps): bump step-security/harden-runner from 2.13.0 to 2.13.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.13.0 to 2.13.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/ec9f2d5744a09debf3a187a3f4f675c53b671911...f4a75cfd619ee5ce8d5b864b0d183aff3c69b55a)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-version: 2.13.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e0fffae`](https://github.com/OZI-Project/ozi-spec/commit/e0fffaeebb844fec2a98a5bde3cbebf3be44f59b))

* build(deps): bump github/codeql-action from 3.30.0 to 3.30.2

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.30.0 to 3.30.2.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/2d92b76c45b91eb80fc44c74ce3fce0ee94e8f9d...d3678e237b9c32a6c9bffb3315c335f976f3549f)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.30.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`a5da848`](https://github.com/OZI-Project/ozi-spec/commit/a5da848efac9c2620e55cbf1d29d1b51cd4ad3df))

* build(deps): bump the ozi group with 5 updates

Bumps the ozi group with 5 updates:

| Package | From | To |
|  |  |  |
| [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) | `1.9.9` | `1.10.0` |
| [OZI-Project/draft](https://github.com/ozi-project/draft) | `1.17.2` | `1.17.3` |
| [OZI-Project/release](https://github.com/ozi-project/release) | `1.9.1` | `1.10.0` |
| [OZI-Project/provenance](https://github.com/ozi-project/provenance) | `0.1.0` | `1.0.0` |
| [OZI-Project/publish](https://github.com/ozi-project/publish) | `1.17.2` | `1.17.3` |


Updates `OZI-Project/checkpoint` from 1.9.9 to 1.10.0
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/bc80bd040b1b6705a270fc6b111b08dfe6cde16b...1faf4433bbcc31ed6a0104896a92564d94182b20)

Updates `OZI-Project/draft` from 1.17.2 to 1.17.3
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/4f3dcb71f8251f1e8238eb011aa12dd6a9020d23...3df8701fb8fbda746814804dcdc1b6e7533d4fe8)

Updates `OZI-Project/release` from 1.9.1 to 1.10.0
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/eb10d9730ae9ad7c7c63e016d714013b4e017d5d...60a6112177f9e232a55f0d2dfe3aa0d2da322cf1)

Updates `OZI-Project/provenance` from 0.1.0 to 1.0.0
- [Release notes](https://github.com/ozi-project/provenance/releases)
- [Commits](https://github.com/ozi-project/provenance/compare/a7369a6ef4a56f442b97615539b8de23dcb1e94e...9a0953f8937c2d16844fcf5f79f6295058bebbd3)

Updates `OZI-Project/publish` from 1.17.2 to 1.17.3
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/4f60b808859fd63bd4be3bb9cc3e34d7a14c3bf7...c3ea682a04a1458e0edc4886979850a647304677)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.10.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
  dependency-group: ozi
- dependency-name: OZI-Project/draft
  dependency-version: 1.17.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
  dependency-group: ozi
- dependency-name: OZI-Project/release
  dependency-version: 1.10.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
  dependency-group: ozi
- dependency-name: OZI-Project/provenance
  dependency-version: 1.0.0
  dependency-type: direct:production
  update-type: version-update:semver-major
  dependency-group: ozi
- dependency-name: OZI-Project/publish
  dependency-version: 1.17.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
  dependency-group: ozi
... — dependabot[bot] <support@github.com>
([`1d13415`](https://github.com/OZI-Project/ozi-spec/commit/1d13415035871238cffa922906e65c5469d5ed34))

## 1.1.7 (2025-09-06)

## 1.1.6 (2025-08-30)


### Build system


* build(deps): bump pypa/gh-action-pypi-publish from 1.12.4 to 1.13.0

Bumps [pypa/gh-action-pypi-publish](https://github.com/pypa/gh-action-pypi-publish) from 1.12.4 to 1.13.0.
- [Release notes](https://github.com/pypa/gh-action-pypi-publish/releases)
- [Commits](https://github.com/pypa/gh-action-pypi-publish/compare/76f52bc884231f62b9a034ebfe128415bbaabdfc...ed0c53931b1dc9bd32cbe73a98c7f6766f8a527e)


updated-dependencies:
- dependency-name: pypa/gh-action-pypi-publish
  dependency-version: 1.13.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`7879007`](https://github.com/OZI-Project/ozi-spec/commit/787900786950aa8a0b221be932f15bf34d8340ec))

* build(deps): bump github/codeql-action from 3.29.11 to 3.30.0

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.29.11 to 3.30.0.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/3c3833e0f8c1c83d449a7478aa59c036a9165498...2d92b76c45b91eb80fc44c74ce3fce0ee94e8f9d)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.30.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`b0817fe`](https://github.com/OZI-Project/ozi-spec/commit/b0817fe6dbdf6aef1ba32b21cbd1adcb0f3fda0c))

* build(deps): bump github/codeql-action from 3.29.10 to 3.29.11

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.29.10 to 3.29.11.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/96f518a34f7a870018057716cc4d7a5c014bd61c...3c3833e0f8c1c83d449a7478aa59c036a9165498)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.29.11
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`db2f40d`](https://github.com/OZI-Project/ozi-spec/commit/db2f40dd94294b11c57ade7e1a343a95e8eba424))

* build(deps): bump actions/dependency-review-action from 4.7.2 to 4.7.3

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.7.2 to 4.7.3.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/bc41886e18ea39df68b1b1245f4184881938e050...595b5aeba73380359d98a5e087f648dbb0edce1b)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-version: 4.7.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`d624760`](https://github.com/OZI-Project/ozi-spec/commit/d6247605d19ddfe17fb3aca45c6c92a92a2e240f))

* build(deps): bump OZI-Project/checkpoint in the ozi group

Bumps the ozi group with 1 update: [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint).


Updates `OZI-Project/checkpoint` from 1.9.6 to 1.9.9
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/567295409c0cf62e340aa3457550509a0fa7e5cf...bc80bd040b1b6705a270fc6b111b08dfe6cde16b)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.9.9
  dependency-type: direct:production
  update-type: version-update:semver-patch
  dependency-group: ozi
... — dependabot[bot] <support@github.com>
([`0a57b15`](https://github.com/OZI-Project/ozi-spec/commit/0a57b15c49b5d88f0860009d75987685bc7e3805))

## 1.1.5 (2025-08-21)


### Build system


* build(deps): bump actions/dependency-review-action from 4.7.1 to 4.7.2

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.7.1 to 4.7.2.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/da24556b548a50705dd671f47852072ea4c105d9...bc41886e18ea39df68b1b1245f4184881938e050)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-version: 4.7.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`915ece1`](https://github.com/OZI-Project/ozi-spec/commit/915ece186a618c1374109b2cdbb9bbcca8641d5b))

* build(deps): bump the ozi group with 4 updates

Bumps the ozi group with 4 updates: [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint), [OZI-Project/draft](https://github.com/ozi-project/draft), [OZI-Project/release](https://github.com/ozi-project/release) and [OZI-Project/publish](https://github.com/ozi-project/publish).


Updates `OZI-Project/checkpoint` from 1.9.5 to 1.9.6
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/f475dbf6078211f784f6e7b3bb7c1b00ce0d05b9...567295409c0cf62e340aa3457550509a0fa7e5cf)

Updates `OZI-Project/draft` from 1.17.0 to 1.17.2
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/cabcb89f38f90863aa0217f0b4b2dba02262b004...4f3dcb71f8251f1e8238eb011aa12dd6a9020d23)

Updates `OZI-Project/release` from 1.9.0 to 1.9.1
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/d3920f3f0471dec9369a2245cc6e6b42756d27f8...eb10d9730ae9ad7c7c63e016d714013b4e017d5d)

Updates `OZI-Project/publish` from 1.17.0 to 1.17.2
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/ed9bff22f51f8b70c47a326e1e73a48174a8c6d2...4f60b808859fd63bd4be3bb9cc3e34d7a14c3bf7)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.9.6
  dependency-type: direct:production
  update-type: version-update:semver-patch
  dependency-group: ozi
- dependency-name: OZI-Project/draft
  dependency-version: 1.17.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
  dependency-group: ozi
- dependency-name: OZI-Project/release
  dependency-version: 1.9.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
  dependency-group: ozi
- dependency-name: OZI-Project/publish
  dependency-version: 1.17.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
  dependency-group: ozi
... — dependabot[bot] <support@github.com>
([`1a67fa9`](https://github.com/OZI-Project/ozi-spec/commit/1a67fa9597466e3a33fcd55311e9588ce107329a))

* build(deps): bump github/codeql-action from 3.29.9 to 3.29.10

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.29.9 to 3.29.10.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/df559355d593797519d70b90fc8edd5db049e7a2...96f518a34f7a870018057716cc4d7a5c014bd61c)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.29.10
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`cd4b172`](https://github.com/OZI-Project/ozi-spec/commit/cd4b17234dbac58866ce0a301e6108deb538dd66))

* build(deps): bump github/codeql-action from 3.29.7 to 3.29.9

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.29.7 to 3.29.9.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/51f77329afa6477de8c49fc9c7046c15b9a4e79d...df559355d593797519d70b90fc8edd5db049e7a2)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.29.9
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`98e23ef`](https://github.com/OZI-Project/ozi-spec/commit/98e23efcb91878a1593664fd1377bf8e01e6bdab))

* build(deps): bump actions/checkout from 4.2.2 to 5.0.0

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.2.2 to 5.0.0.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/11bd71901bbe5b1630ceea73d27597364c9af683...08c6903cd8c0fde910a37f88322edcfb5dd907a8)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-version: 5.0.0
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`c2b4f86`](https://github.com/OZI-Project/ozi-spec/commit/c2b4f86cadaafd9f8cf553f6616c8c6d73413500))


### Unknown


* Update dependabot.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`91d5b94`](https://github.com/OZI-Project/ozi-spec/commit/91d5b94c751e4f621d4fbe73265c615bab1dc118))

* Update dependabot.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`d0f34fb`](https://github.com/OZI-Project/ozi-spec/commit/d0f34fb1958986a7c8ed4311991eb598440e41ca))

## 1.1.4 (2025-08-08)


### Bug fixes


* fix: update dev.yml endpoints — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`b8e49f2`](https://github.com/OZI-Project/ozi-spec/commit/b8e49f21efc2903d335ed60fd3256dd1c05bcc58))

* fix: add endpoint release-assets.githubusercontent.com — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`1add354`](https://github.com/OZI-Project/ozi-spec/commit/1add354c68bb0d03d7d3bf278e5fc06573880904))

## 1.1.3 (2025-08-05)


### Build system


* build(deps): bump OZI-Project/publish from 1.16.0 to 1.17.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.16.0 to 1.17.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/9df2afca0ca23d527508e76a8deef37330bd90bb...ed9bff22f51f8b70c47a326e1e73a48174a8c6d2)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.17.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`16c2e76`](https://github.com/OZI-Project/ozi-spec/commit/16c2e7690ef8a480e7d57c78418006c6717d810c))

* build(deps): bump github/codeql-action from 3.29.4 to 3.29.5

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.29.4 to 3.29.5.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/4e828ff8d448a8a6e532957b1811f387a63867e8...51f77329afa6477de8c49fc9c7046c15b9a4e79d)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.29.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`69ccd15`](https://github.com/OZI-Project/ozi-spec/commit/69ccd15d62527d21c3b96bfe5131cd83ed689afd))

* build(deps): bump OZI-Project/draft from 1.16.0 to 1.17.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.16.0 to 1.17.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/7ce5c1150603d27957375d1c85570faa29ab5fd5...cabcb89f38f90863aa0217f0b4b2dba02262b004)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.17.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`dd97341`](https://github.com/OZI-Project/ozi-spec/commit/dd973415879203c3d0de875859cfdad72d1ec078))

* build(deps): bump OZI-Project/checkpoint from 1.9.4 to 1.9.5

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.9.4 to 1.9.5.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/e6919d1fe476e76ce08cb6e85f847d0bf6dd8b6e...f475dbf6078211f784f6e7b3bb7c1b00ce0d05b9)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.9.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`6ec27d5`](https://github.com/OZI-Project/ozi-spec/commit/6ec27d5326c79c54cdb91cab10cd030329c14a39))

## 1.1.2 (2025-07-26)


### Build system


* build(deps): bump OZI-Project/release from 1.8.11 to 1.9.0

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.8.11 to 1.9.0.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/3b2d9beadc38335e9fdace1dc21d7d5807d7be76...d3920f3f0471dec9369a2245cc6e6b42756d27f8)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.9.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`5b969f4`](https://github.com/OZI-Project/ozi-spec/commit/5b969f483fbc809e5d70e6e9c31e9cc2ec717824))

* build(deps): bump github/codeql-action from 3.29.2 to 3.29.4

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.29.2 to 3.29.4.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/181d5eefc20863364f96762470ba6f862bdef56b...4e828ff8d448a8a6e532957b1811f387a63867e8)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.29.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`70bad57`](https://github.com/OZI-Project/ozi-spec/commit/70bad571834753e484c84bee9be2451d1f3faf8d))

* build(deps): bump OZI-Project/checkpoint from 1.9.3 to 1.9.4

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.9.3 to 1.9.4.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/4c60c58ba33a128bbde246fbee9e16569062f7cf...e6919d1fe476e76ce08cb6e85f847d0bf6dd8b6e)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.9.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`3af0684`](https://github.com/OZI-Project/ozi-spec/commit/3af0684ab639687202d252d81edeb4c44d9818a3))

## 1.1.1 (2025-07-17)


### Bug fixes


* fix: add release-assets.githubusercontent.com:443 endpoint to release — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`0d3349d`](https://github.com/OZI-Project/ozi-spec/commit/0d3349d4d35b60f5baaef45d3b82b671eafb31ec))


### Build system


* build(deps): bump step-security/harden-runner from 2.12.2 to 2.13.0


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-version: 2.13.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`de9e0b2`](https://github.com/OZI-Project/ozi-spec/commit/de9e0b23af4a95ae6ec1869357c00c44e0fdb66e))

* build(deps): bump OZI-Project/release from 1.8.10 to 1.8.11

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.8.10 to 1.8.11.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/fd220285eff3de13b0eeab9f0882f245fa55b2e6...3b2d9beadc38335e9fdace1dc21d7d5807d7be76)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.8.11
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`191d035`](https://github.com/OZI-Project/ozi-spec/commit/191d03505098ffeb331579fba1318ec207554d02))

## 1.1.0 (2025-07-09)


### Build system


* build(deps): bump github/codeql-action from 3.29.0 to 3.29.2

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.29.0 to 3.29.2.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/ce28f5bb42b7a9f2c824e633a3f6ee835bab6858...181d5eefc20863364f96762470ba6f862bdef56b)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.29.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`afa9b68`](https://github.com/OZI-Project/ozi-spec/commit/afa9b688b44baf4a7d875ee83e3876d6878d5ec4))

* build(deps): bump OZI-Project/draft from 1.15.0 to 1.16.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.15.0 to 1.16.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/4f9117750cd22709a929ed3f36578f172a94bd41...7ce5c1150603d27957375d1c85570faa29ab5fd5)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.16.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`e3061b9`](https://github.com/OZI-Project/ozi-spec/commit/e3061b93e92185784817cb4b82d7d8976259a1ad))

* build(deps): bump step-security/harden-runner from 2.12.1 to 2.12.2

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.12.1 to 2.12.2.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/002fdce3c6a235733a90a27c80493a3241e56863...6c439dc8bdf85cadbbce9ed30d1c7b959517bc49)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-version: 2.12.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`fc49279`](https://github.com/OZI-Project/ozi-spec/commit/fc49279d9c65e8cab1588812e7e1642e7a498622))

* build(deps): bump OZI-Project/checkpoint from 1.9.1 to 1.9.3

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.9.1 to 1.9.3.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/b7afe55ac890df008deb75191e53f83823117f92...4c60c58ba33a128bbde246fbee9e16569062f7cf)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.9.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`fb5827c`](https://github.com/OZI-Project/ozi-spec/commit/fb5827c62176d98aac79c3e2a944b8abfc9e048c))

* build(deps): bump OZI-Project/publish from 1.15.0 to 1.16.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.15.0 to 1.16.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/c448915d89a76028ab54f2b539ad159e3a612003...9df2afca0ca23d527508e76a8deef37330bd90bb)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.16.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`6e508e1`](https://github.com/OZI-Project/ozi-spec/commit/6e508e1310074b02fb9b898de20e1aa4677ea935))

## 1.0.6 (2025-06-13)


### Build system


* build(deps): bump OZI-Project/draft from 1.14.2 to 1.15.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.14.2 to 1.15.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/d870c506fefd49de075e21217885c8670cd9b883...4f9117750cd22709a929ed3f36578f172a94bd41)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.15.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`41452e5`](https://github.com/OZI-Project/ozi-spec/commit/41452e5d4ebdde3ae4ac9a8cf11e183db06243e3))

* build(deps): bump OZI-Project/publish from 1.14.3 to 1.15.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.14.3 to 1.15.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/d2deb87a158a3555d67cb9dbabde2fe3e271fa6a...c448915d89a76028ab54f2b539ad159e3a612003)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.15.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`44b36ec`](https://github.com/OZI-Project/ozi-spec/commit/44b36ec34c26e7678ed671b5680ff8e78d7663af))

## 1.0.5 (2025-06-12)


### Build system


* build(deps): bump OZI-Project/checkpoint from 1.8.3 to 1.9.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.8.3 to 1.9.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/34c59f4977fed722934fae2caadc29e3f0f8bf0d...b7afe55ac890df008deb75191e53f83823117f92)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.9.1
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`8a42fb8`](https://github.com/OZI-Project/ozi-spec/commit/8a42fb82f4fdd3e401344ae2ce18c7bcda1bd3f3))

* build(deps): bump OZI-Project/release from 1.8.7 to 1.8.10

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.8.7 to 1.8.10.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/067a3867b9df3c1c2b86db5e062ca83c48dbc0bc...fd220285eff3de13b0eeab9f0882f245fa55b2e6)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.8.10
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`4ef08dd`](https://github.com/OZI-Project/ozi-spec/commit/4ef08dd40d6ffb467319ac7be799b6d5107ae7d2))

* build(deps): bump OZI-Project/checkpoint from 1.7.5 to 1.8.3

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.7.5 to 1.8.3.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/301753e6853d6a65055c8df69dafe7df74bd7963...34c59f4977fed722934fae2caadc29e3f0f8bf0d)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.8.3
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`edbb2ca`](https://github.com/OZI-Project/ozi-spec/commit/edbb2caa52c1b48022054562130ad1763a6ecc9b))

* build(deps): bump step-security/harden-runner from 2.12.0 to 2.12.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.12.0 to 2.12.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/0634a2670c59f64b4a01f0f96f84700a4088b9f0...002fdce3c6a235733a90a27c80493a3241e56863)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-version: 2.12.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`2a0e113`](https://github.com/OZI-Project/ozi-spec/commit/2a0e113712031ccac59af4940369b882e98db6bb))

* build(deps): bump github/codeql-action from 3.28.19 to 3.29.0

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.19 to 3.29.0.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/fca7ace96b7d713c7035871441bd52efbe39e27e...ce28f5bb42b7a9f2c824e633a3f6ee835bab6858)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.29.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`ea7cce3`](https://github.com/OZI-Project/ozi-spec/commit/ea7cce3a2f09fe013f7a46055ef6b28d1290d23e))

* build(deps): update ozi-build[core,uv] requirement

Updates the requirements on [ozi-build[core,uv]](https://github.com/OZI-Project/OZI.build) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/OZI.build/releases)
- [Changelog](https://github.com/OZI-Project/OZI.build/blob/master/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/OZI.build/compare/2.2.1...2.3.2)


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-version: 2.3.2
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`248de63`](https://github.com/OZI-Project/ozi-spec/commit/248de63aa5b4e7b9385e585c0e15d95101d6882e))


### Chores


* chore: update OZI wrapfile to 2.1 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`5760eeb`](https://github.com/OZI-Project/ozi-spec/commit/5760eeb782418fac90e95a3a14740e8eef36caec))


### Features


* feat: correct templates path for github workflows — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`451567e`](https://github.com/OZI-Project/ozi-spec/commit/451567e6612c201b6df9fc71daae925d1dde5e3d))

* feat: move checkpoint, draft, release, publish metadata into provider specific keys — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`ffd8d3a`](https://github.com/OZI-Project/ozi-spec/commit/ffd8d3a5912732b7a059330f273eb04e3b4caaaf))

* feat: add github actions native provenance workflow — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`2771b81`](https://github.com/OZI-Project/ozi-spec/commit/2771b81e1310cd5c32c16d927d6e1236ab0b29ba))

## 1.0.4 (2025-06-05)


### Build system


* build(deps): bump OZI-Project/publish from 1.14.0 to 1.14.3

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.14.0 to 1.14.3.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0d8a74931c945399bb0967f77c67055956b9e5c5...d2deb87a158a3555d67cb9dbabde2fe3e271fa6a)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.14.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`d69756f`](https://github.com/OZI-Project/ozi-spec/commit/d69756fa1eceecc739ef17b7d6c8d59328929146))

* build(deps): bump OZI-Project/draft from 1.14.0 to 1.14.2

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.14.0 to 1.14.2.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/9fcb96b0c50c0da405737413299ede083f1d94cf...d870c506fefd49de075e21217885c8670cd9b883)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.14.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`23ce2c9`](https://github.com/OZI-Project/ozi-spec/commit/23ce2c9def147af28422b1d645c7a175de8600d3))

* build(deps): bump OZI-Project/release from 1.8.5 to 1.8.7

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.8.5 to 1.8.7.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/84d51474b41de0c8c98d34431f9c0e282fd72c19...067a3867b9df3c1c2b86db5e062ca83c48dbc0bc)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.8.7
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`5eb4c74`](https://github.com/OZI-Project/ozi-spec/commit/5eb4c74ad05d6023e2507b877712693fa58cfc0d))

* build(deps): bump github/codeql-action from 3.28.18 to 3.28.19

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.18 to 3.28.19.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/ff0a06e83cb2de871e5a09832bc6a81e7276941f...fca7ace96b7d713c7035871441bd52efbe39e27e)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.28.19
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`66cd644`](https://github.com/OZI-Project/ozi-spec/commit/66cd6444e235bd03601bb56753c3b169b67849e1))

## 1.0.3 (2025-06-03)


### Bug fixes


* fix: update for OZI-2.0.3 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`3162495`](https://github.com/OZI-Project/ozi-spec/commit/3162495cc0fb8147d90de68dca224aced72a3c01))


### Build system


* build(deps): bump OZI-Project/release from 1.8.3 to 1.8.5

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.8.3 to 1.8.5.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0a9f46ecacc5bb6a926467a601c8b75bb2deb4ac...84d51474b41de0c8c98d34431f9c0e282fd72c19)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.8.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`07e2f69`](https://github.com/OZI-Project/ozi-spec/commit/07e2f699ebc8eb2380db5b4e5607c3f2ed31c712))

* build(deps): bump ossf/scorecard-action from 2.4.1 to 2.4.2

Bumps [ossf/scorecard-action](https://github.com/ossf/scorecard-action) from 2.4.1 to 2.4.2.
- [Release notes](https://github.com/ossf/scorecard-action/releases)
- [Changelog](https://github.com/ossf/scorecard-action/blob/main/RELEASE.md)
- [Commits](https://github.com/ossf/scorecard-action/compare/f49aabe0b5af0936a0987cfb85d86b75731b0186...05b42c624433fc40578a4040d5cf5e36ddca8cde)


updated-dependencies:
- dependency-name: ossf/scorecard-action
  dependency-version: 2.4.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`bd2ed24`](https://github.com/OZI-Project/ozi-spec/commit/bd2ed24503ffa12ce4331fb1fc774f3567fad8b1))


### Chores


* chore: ozi.wrap updated to 2.0.18 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`09c3099`](https://github.com/OZI-Project/ozi-spec/commit/09c3099be513a5057d22a734c200f09a6701ac42))

* chore: update wrapfile to OZI-2.0.2 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`1014a37`](https://github.com/OZI-Project/ozi-spec/commit/1014a378659d824331d8401c7ff265f2c20fd346))

## 1.0.2 (2025-05-30)


### Build system


* build(deps): bump OZI-Project/checkpoint from 1.7.4 to 1.7.5

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.7.4 to 1.7.5.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/40890b7e9f18621e556892606346aebc8292cfa6...301753e6853d6a65055c8df69dafe7df74bd7963)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.7.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`3113413`](https://github.com/OZI-Project/ozi-spec/commit/3113413786d1875ee4d7b1dcb60debf52110f010))

## 1.0.1 (2025-05-29)


### Bug fixes


* fix: remove sematic-release changelog and release notes templates — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`3ebb2f3`](https://github.com/OZI-Project/ozi-spec/commit/3ebb2f348cf8a9b09470aa1d6734bcb33ad916f8))

* fix: clean up stubs for major version 1 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`7cec0b8`](https://github.com/OZI-Project/ozi-spec/commit/7cec0b8980d6b541c7c871a3c335ffbc1c9a780f))


### Chores


* chore: update release branches — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`29081a0`](https://github.com/OZI-Project/ozi-spec/commit/29081a02dcbd02710a42c021bd9499e10358c62c))

* chore: clean up lint — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`bf658f1`](https://github.com/OZI-Project/ozi-spec/commit/bf658f105d15b0889de93bcf5e259b389a0565e9))

## 1.0.0 (2025-05-28)


### Build system


* build(deps): bump OZI-Project/publish from 1.13.8 to 1.14.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.8 to 1.14.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/39cc73091234a1dc42b933df3d965318966e65a2...0d8a74931c945399bb0967f77c67055956b9e5c5)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.14.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`d71e8f6`](https://github.com/OZI-Project/ozi-spec/commit/d71e8f6c6fafeb7d6c96ab2d1cb4be6ff708c1c7))

* build(deps): bump OZI-Project/draft from 1.13.5 to 1.14.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.13.5 to 1.14.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/fbf34233ed3d0719d994c2172ac767644c97a2aa...9fcb96b0c50c0da405737413299ede083f1d94cf)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.14.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`b7bf3e3`](https://github.com/OZI-Project/ozi-spec/commit/b7bf3e386d8df8266d06b292fcf2e88e1eff1543))

* build(deps): bump OZI-Project/publish from 1.13.7 to 1.13.8

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.7 to 1.13.8.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/621f1f7d2691300b8a66b0aaa62a4853359daa89...39cc73091234a1dc42b933df3d965318966e65a2)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.8
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`2059ef4`](https://github.com/OZI-Project/ozi-spec/commit/2059ef42c32707981573ae8b9bb2806c908a17d3))

* build(deps): bump github/codeql-action from 3.28.17 to 3.28.18

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.17 to 3.28.18.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/60168efe1c415ce0f5521ea06d5c2062adbeed1b...ff0a06e83cb2de871e5a09832bc6a81e7276941f)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.28.18
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f04e7cc`](https://github.com/OZI-Project/ozi-spec/commit/f04e7cca79f54ed5bc80060edaf3136184b73ef6))

* build(deps): bump OZI-Project/draft from 1.13.4 to 1.13.5

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.13.4 to 1.13.5.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/84f054f0398fe815ac68f4243f6aafb9f5b85e4a...fbf34233ed3d0719d994c2172ac767644c97a2aa)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.13.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e17ee87`](https://github.com/OZI-Project/ozi-spec/commit/e17ee87b51b7c36488516d76b89bb5bf47b941b7))

* build(deps): bump OZI-Project/release from 1.7.8 to 1.8.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.7.8 to 1.8.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0bd5001b3e0b5585643aa8f831a4d504126ad411...0a9f46ecacc5bb6a926467a601c8b75bb2deb4ac)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.8.3
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`f583c6e`](https://github.com/OZI-Project/ozi-spec/commit/f583c6e43a96ff766cc94df56a8b2c46790d6e11))

* build(deps): bump OZI-Project/checkpoint from 1.7.3 to 1.7.4

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.7.3 to 1.7.4.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1b0b165711dca7c852f4c30fbebea96de3747617...40890b7e9f18621e556892606346aebc8292cfa6)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.7.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`0a27f37`](https://github.com/OZI-Project/ozi-spec/commit/0a27f371891f309d276af0109030db8db69b750c))

## 0.28.6 (2025-05-15)


### Build system


* build(deps): bump OZI-Project/release from 1.7.7 to 1.7.8

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.7.7 to 1.7.8.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/862f61adc1c28749876fe3d09b386b217ca1cbd6...0bd5001b3e0b5585643aa8f831a4d504126ad411)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.7.8
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`68382b8`](https://github.com/OZI-Project/ozi-spec/commit/68382b831c1a9330c8dbf78995acb4747f431699))

## 0.28.5 (2025-05-15)


### Build system


* build(deps): bump OZI-Project/release from 1.7.6 to 1.7.7

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.7.6 to 1.7.7.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/14c90775d0efe9f0f69a914d05cc9319bfc632a0...862f61adc1c28749876fe3d09b386b217ca1cbd6)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.7.7
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`7f321eb`](https://github.com/OZI-Project/ozi-spec/commit/7f321ebf5d2dad4e9a9d5b2141ce67b5bd4b2b36))

## 0.28.4 (2025-05-14)


### Build system


* build(deps): bump OZI-Project/release from 1.7.5 to 1.7.6

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.7.5 to 1.7.6.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/3a4dccb29fe06b0d9f3ff299321abeb19f165fcb...14c90775d0efe9f0f69a914d05cc9319bfc632a0)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.7.6
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`62d8d1f`](https://github.com/OZI-Project/ozi-spec/commit/62d8d1fd60cfa3b0d723f74573328995daf491fa))

* build(deps): bump OZI-Project/release from 1.7.4 to 1.7.5

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.7.4 to 1.7.5.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/7b3bc0282c162a771c69e91decca3e3ba792e221...3a4dccb29fe06b0d9f3ff299321abeb19f165fcb)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.7.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`45972b5`](https://github.com/OZI-Project/ozi-spec/commit/45972b5d4deba94146047a5ab4dffcada8021b57))

* build(deps): bump actions/dependency-review-action from 4.7.0 to 4.7.1

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.7.0 to 4.7.1.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/38ecb5b593bf0eb19e335c03f97670f792489a8b...da24556b548a50705dd671f47852072ea4c105d9)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-version: 4.7.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`6c58c0a`](https://github.com/OZI-Project/ozi-spec/commit/6c58c0a2f3ed845d10f87879aa70dce99fbaa807))

## 0.28.3 (2025-05-13)


### Build system


* build(deps): bump OZI-Project/release from 1.7.3 to 1.7.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.7.3 to 1.7.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/da01e3a2105d7c014ba240b23b97f19a9f3cdd95...7b3bc0282c162a771c69e91decca3e3ba792e221)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.7.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e450810`](https://github.com/OZI-Project/ozi-spec/commit/e450810b96e8d980bc35ee1b9f8760fbe6e45a0b))

* build(deps): bump OZI-Project/release from 1.7.2 to 1.7.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.7.2 to 1.7.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1a96f575984b14a83263245632390143af65fc7c...da01e3a2105d7c014ba240b23b97f19a9f3cdd95)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.7.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`800b2a0`](https://github.com/OZI-Project/ozi-spec/commit/800b2a0393e99bed1a5434fbe9f1d549ee20d21a))

* build(deps): bump OZI-Project/release from 1.7.1 to 1.7.2

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.7.1 to 1.7.2.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/cc342b5a9127bac0d35e19df985e508d3e2970d9...1a96f575984b14a83263245632390143af65fc7c)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.7.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`5168477`](https://github.com/OZI-Project/ozi-spec/commit/516847760068f62883acdaf9eb5f86505ed78181))

* build: ozi.wrap 1.41.9 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`abb9d54`](https://github.com/OZI-Project/ozi-spec/commit/abb9d547a10f8adf9293f8331fafdfc092f61de8))

* build(deps): bump OZI-Project/release from 1.7.0 to 1.7.1

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.7.0 to 1.7.1.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/f1ee8e62757fbe1f21b773ff39636ab296a0a5be...cc342b5a9127bac0d35e19df985e508d3e2970d9)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.7.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`146ae7d`](https://github.com/OZI-Project/ozi-spec/commit/146ae7d050744f1028f4f4abf894fe7b17ac3093))

* build(deps): bump OZI-Project/release from 1.6.7 to 1.7.0

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.6.7 to 1.7.0.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/10a57d8906c4969547cfaa3395eb53facb8a5041...f1ee8e62757fbe1f21b773ff39636ab296a0a5be)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.7.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`371b320`](https://github.com/OZI-Project/ozi-spec/commit/371b3204da94e5998ba8a46eb9a61a5efb52da1b))

* build(deps): bump OZI-Project/publish from 1.13.6 to 1.13.7

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.6 to 1.13.7.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/d1763d63541169af7572fbe3c3b6ea9ffc2d355c...621f1f7d2691300b8a66b0aaa62a4853359daa89)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.7
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`1b2e1dd`](https://github.com/OZI-Project/ozi-spec/commit/1b2e1dded3b87e9e3e3b7f83ff4dcb04b286fa63))


### Unknown


* Update meson.build — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`3d535c6`](https://github.com/OZI-Project/ozi-spec/commit/3d535c6dc9fe95e2652750f1240e8d1b65df543e))

## 0.28.2 (2025-05-10)


### Build system


* build(deps): bump OZI-Project/release from 1.6.6 to 1.6.7

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.6.6 to 1.6.7.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/c2763a6a1958b2eca8679748d58a09f9819dff74...10a57d8906c4969547cfaa3395eb53facb8a5041)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.6.7
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`d854aa0`](https://github.com/OZI-Project/ozi-spec/commit/d854aa010a690278013bd3539b1a93d63534c6e2))

* build(deps): bump OZI-Project/draft from 1.13.2 to 1.13.4

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.13.2 to 1.13.4.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/92712f8a95c9cb1fa00731f9a29edeb1cd9799b8...84f054f0398fe815ac68f4243f6aafb9f5b85e4a)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.13.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e71a0de`](https://github.com/OZI-Project/ozi-spec/commit/e71a0debe59e84937ad45a0ef849f82b526d4f68))

* build(deps): bump OZI-Project/checkpoint from 1.7.2 to 1.7.3

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.7.2 to 1.7.3.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/ac9e45ece7eecacce1a9acb44ae4443985fe310b...1b0b165711dca7c852f4c30fbebea96de3747617)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.7.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`42e13f0`](https://github.com/OZI-Project/ozi-spec/commit/42e13f0f66135ccb4b308ce0ff6602bdc908203a))

* build(deps): bump OZI-Project/release from 1.6.5 to 1.6.6

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.6.5 to 1.6.6.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/36fe15c47185192e9cf5df744a8d1eb679676e22...c2763a6a1958b2eca8679748d58a09f9819dff74)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.6.6
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`523e022`](https://github.com/OZI-Project/ozi-spec/commit/523e0226b2d7d9f4b4d065cf58902bd442ec43eb))

* build(deps): bump OZI-Project/publish from 1.13.4 to 1.13.6

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.4 to 1.13.6.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/8297bf52054be7cae27ab2770e08d96676fd3162...d1763d63541169af7572fbe3c3b6ea9ffc2d355c)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.6
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`788c7a1`](https://github.com/OZI-Project/ozi-spec/commit/788c7a198de3a1381ef6ea13a4717b83466d4c46))

* build(deps): bump github/codeql-action from 3.28.16 to 3.28.17

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.16 to 3.28.17.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/28deaeda66b76a05916b6923827895f2b14ab387...60168efe1c415ce0f5521ea06d5c2062adbeed1b)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.28.17
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`53d7908`](https://github.com/OZI-Project/ozi-spec/commit/53d790898b6b3da5f7838542b9e72b0b4e491b94))

* build(deps): bump actions/dependency-review-action from 4.6.0 to 4.7.0

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.6.0 to 4.7.0.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/ce3cf9537a52e8119d91fd484ab5b8a807627bf8...38ecb5b593bf0eb19e335c03f97670f792489a8b)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-version: 4.7.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`23ffa73`](https://github.com/OZI-Project/ozi-spec/commit/23ffa7393455d55756f1a6144cc9dd23673df69b))

* build(deps): update ozi-build[core,uv] requirement

Updates the requirements on [ozi-build[core,uv]](https://github.com/OZI-Project/OZI.build) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/OZI.build/releases)
- [Changelog](https://github.com/OZI-Project/OZI.build/blob/master/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/OZI.build/compare/2.0.9...2.2.1)


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-version: 2.2.1
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`0a99de0`](https://github.com/OZI-Project/ozi-spec/commit/0a99de0b3508c02d4cad44ca00956023e9ec0aa8))


### Unknown


* Update dependabot.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`b4acd67`](https://github.com/OZI-Project/ozi-spec/commit/b4acd67b6aa1b82a2ad61e51477c7517f91475e1))

## 0.28.1 (2025-05-01)


### Build system


* build(deps): bump OZI-Project/publish from 1.13.3 to 1.13.4

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.3 to 1.13.4.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/df67e9c0f38d22c078568807d2eefed313340e2d...8297bf52054be7cae27ab2770e08d96676fd3162)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`2977748`](https://github.com/OZI-Project/ozi-spec/commit/29777487b033bb77e57cf13fcaf0e8bf37e945a9))

* build(deps): bump OZI-Project/checkpoint from 1.7.1 to 1.7.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.7.1 to 1.7.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/dbe6f38e4bb6ed375129d0cf718b6d6968340a13...ac9e45ece7eecacce1a9acb44ae4443985fe310b)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.7.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9a7f548`](https://github.com/OZI-Project/ozi-spec/commit/9a7f54860042faf9d1d19fb5b5e36620a8b541b7))

* build(deps): bump OZI-Project/release from 1.6.4 to 1.6.5

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.6.4 to 1.6.5.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0b2ba9981ee9eea47a358c0d70c5b3764a61b88c...36fe15c47185192e9cf5df744a8d1eb679676e22)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.6.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9a24440`](https://github.com/OZI-Project/ozi-spec/commit/9a244404dda1a7e70d60ab0ef8151e06906acaf3))

* build(deps): bump OZI-Project/draft from 1.13.1 to 1.13.2

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.13.1 to 1.13.2.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/ed08d630ad83cfd14061b78cf695c20eb51984a5...92712f8a95c9cb1fa00731f9a29edeb1cd9799b8)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.13.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`d34614a`](https://github.com/OZI-Project/ozi-spec/commit/d34614a50a3ca708329dce6d7531a45f2e16d778))

* build: OZI.build~=2.0.9 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`757efe2`](https://github.com/OZI-Project/ozi-spec/commit/757efe22b8116e6743ebb8d3cc82a95dfe65ba80))


### Unknown


* Update pyproject.toml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`eef2db5`](https://github.com/OZI-Project/ozi-spec/commit/eef2db5cb8ddc83dea51d78ea9dabfc49b355f7f))

## 0.28.0 (2025-05-01)

## 0.27.3 (2025-04-26)


### Bug fixes


* fix: OZI.build~=2.0.8 - overwrite sdist version with supply-chain provisioned version — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`c9cd1e0`](https://github.com/OZI-Project/ozi-spec/commit/c9cd1e0fe110c30b36849607a663713e7fa5bf7a))

## 0.27.2 (2025-04-26)


### Bug fixes


* fix: update OZI.build to 2.0.7 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`896ce12`](https://github.com/OZI-Project/ozi-spec/commit/896ce12c192e976ba54ae3d9b276b4bb9fd43191))

* fix: add index.crates.io endpoint to freethreaded checkpoint — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`f567960`](https://github.com/OZI-Project/ozi-spec/commit/f567960d7de95c5c10d2a9afa3067030c08b20bd))

## 0.27.1 (2025-04-25)


### Bug fixes


* fix: set requires-python to >=3.9

This fixes dependabot compatibility — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`8bec709`](https://github.com/OZI-Project/ozi-spec/commit/8bec709fb596490348563882a6d961c8e7a30159))

## 0.27.0 (2025-04-24)


### Bug fixes


* fix: remove version from dynamic field — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`fffefdd`](https://github.com/OZI-Project/ozi-spec/commit/fffefdd9b21789eb30212cc8a9e024feda9b948f))

* fix: ignore FutureWarning in pre 3.11 test env — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`2e8ba29`](https://github.com/OZI-Project/ozi-spec/commit/2e8ba29991ad7d25049dbd9cbc6e371e5009dbcb))

* fix: suppress FutureWarning in pre 3.11 test env — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`fcfb07a`](https://github.com/OZI-Project/ozi-spec/commit/fcfb07a5a08f974a393344916dd128657749df22))

* fix: OZI.build~=2.0.5 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`8f5496c`](https://github.com/OZI-Project/ozi-spec/commit/8f5496ca1495f82b7933332213f51564275747fa))

* fix: correct install tag for configured python files with templates — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`44fe178`](https://github.com/OZI-Project/ozi-spec/commit/44fe178f5157ecc9d2197d555d5bb7530e8c9d67))


### Build system


* build(deps): bump OZI-Project/release from 1.6.3 to 1.6.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.6.3 to 1.6.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/8a741f2f740faf147852a35ec27820f9c7ed5ca5...0b2ba9981ee9eea47a358c0d70c5b3764a61b88c)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.6.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9dd9b2e`](https://github.com/OZI-Project/ozi-spec/commit/9dd9b2ecd524c0fbdb6e8d3e913009fd486daf73))

* build(deps): bump OZI-Project/release from 1.6.2 to 1.6.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.6.2 to 1.6.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/3e592628a9ca610fde525ebd15cfa2fe1289f0cb...8a741f2f740faf147852a35ec27820f9c7ed5ca5)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.6.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`cf6bb20`](https://github.com/OZI-Project/ozi-spec/commit/cf6bb2078bf823eddb78748a9e25d18b276628ff))

* build(deps): bump OZI-Project/release from 1.6.1 to 1.6.2

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.6.1 to 1.6.2.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/20ec154dfaf0436e1a2498a21d9e4983b0805a4f...3e592628a9ca610fde525ebd15cfa2fe1289f0cb)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.6.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f3ad006`](https://github.com/OZI-Project/ozi-spec/commit/f3ad0066d1008568361285efe3d1ef4dbfa14e54))

* build(deps): bump OZI-Project/release from 1.6.0 to 1.6.1

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.6.0 to 1.6.1.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/afbdfe0866a7b046820c232d2a8c3256d2d70ed7...20ec154dfaf0436e1a2498a21d9e4983b0805a4f)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.6.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e69f451`](https://github.com/OZI-Project/ozi-spec/commit/e69f4519c442d93e49e18662ad5a17e68a4aa4ea))

* build(deps): bump step-security/harden-runner from 2.11.1 to 2.12.0

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.11.1 to 2.12.0.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/c6295a65d1254861815972266d5933fd6e532bdf...0634a2670c59f64b4a01f0f96f84700a4088b9f0)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-version: 2.12.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`dadd356`](https://github.com/OZI-Project/ozi-spec/commit/dadd35671206e39885f6c854e0dd45391b634e37))

* build(deps): bump github/codeql-action from 3.28.12 to 3.28.16

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.12 to 3.28.16.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/5f8171a638ada777af81d42b55959a643bb29017...28deaeda66b76a05916b6923827895f2b14ab387)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.28.16
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`cfcfc4c`](https://github.com/OZI-Project/ozi-spec/commit/cfcfc4c8f203a7f4bc48d6fc8fa79d8d8f33024d))

* build(deps): update ozi-build[core,uv] requirement

Updates the requirements on [ozi-build[core,uv]](https://github.com/OZI-Project/OZI.build) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/OZI.build/releases)
- [Changelog](https://github.com/OZI-Project/OZI.build/blob/2.0.2/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/OZI.build/compare/1.14.0...2.0.2)


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-version: 2.0.2
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`df9d176`](https://github.com/OZI-Project/ozi-spec/commit/df9d1764dc883c5407a5be52c5bf4aa62470899c))


### Chores


* chore: update OZI.build to latest patch — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`9007b91`](https://github.com/OZI-Project/ozi-spec/commit/9007b917275d49e2c461ff4bc4a5771a37d8757f))

* chore: add pip extra for OZI.build 2.0 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`35d02f5`](https://github.com/OZI-Project/ozi-spec/commit/35d02f5f997f018b3256d69637f6aad1d9eeeb2f))

* chore: update OZI wrapfile to 1.38.4 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`c0cf36e`](https://github.com/OZI-Project/ozi-spec/commit/c0cf36eef5a40e26674ac7386a1a4e900d80cf24))


### Features


* feat: add meson key to build — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`f8b895e`](https://github.com/OZI-Project/ozi-spec/commit/f8b895e2b96e18f7d60a9e8ba9a116b98ad72739))

* feat: default to OZI.build~=2.0.3

Project metadata moved to standard project table in pyproject — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`f4fd08c`](https://github.com/OZI-Project/ozi-spec/commit/f4fd08c880b3d1e1b51177bb47e0fdc7c0efcbc1))

## 0.26.0 (2025-04-20)


### Build system


* build(deps): bump OZI-Project/publish from 1.13.2 to 1.13.3

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.2 to 1.13.3.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/32e7c7b76d44a458dc7538ddc1645520185aa391...df67e9c0f38d22c078568807d2eefed313340e2d)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`b0191e1`](https://github.com/OZI-Project/ozi-spec/commit/b0191e13b4a56b56bdf4e198f63adc7dcc44de5e))

* build: automatic PR creation on publish — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`24872df`](https://github.com/OZI-Project/ozi-spec/commit/24872df4bd7d4df43f6e602e2b171089167757b9))

* build: catch warning for pending deprecation python versions — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`7b3d927`](https://github.com/OZI-Project/ozi-spec/commit/7b3d9274631c62bf1c6612002a2dab1e80af80c5))

* build: add freethreaded 3.13 checkpoint — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`72543b2`](https://github.com/OZI-Project/ozi-spec/commit/72543b2690e68f2d33c5ded2a8ecb3050ef8c65e))

* build(deps): update ozi-build[core,uv] requirement

Updates the requirements on [ozi-build[core,uv]](https://github.com/OZI-Project/OZI.build) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/OZI.build/releases)
- [Changelog](https://github.com/OZI-Project/OZI.build/blob/master/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/OZI.build/compare/1.13.0...1.14.0)


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-version: 1.14.0
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`146e17d`](https://github.com/OZI-Project/ozi-spec/commit/146e17d18aef438bb142ba42c100c74150a0ad80))

* build(deps): bump OZI-Project/checkpoint from 1.7.0 to 1.7.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.7.0 to 1.7.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/bec3d96cd1cb3bbce358fbeabc70eb25482bd3bf...dbe6f38e4bb6ed375129d0cf718b6d6968340a13)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.7.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`003fb89`](https://github.com/OZI-Project/ozi-spec/commit/003fb89b5df63538e179e03089cb6fb001d07632))

* build(deps): bump OZI-Project/publish from 1.13.1 to 1.13.2

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.1 to 1.13.2.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/26f38aa55610d51537ae92c1e89464a18959ba90...32e7c7b76d44a458dc7538ddc1645520185aa391)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`3a2085a`](https://github.com/OZI-Project/ozi-spec/commit/3a2085a303a28f236f8536cb3fa28c133dd90974))

* build(deps): bump OZI-Project/release from 1.5.0 to 1.6.0

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.5.0 to 1.6.0.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/924761bcd1ad9c77bbc34363118b2cee4334b8a5...afbdfe0866a7b046820c232d2a8c3256d2d70ed7)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.6.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`d0c11a5`](https://github.com/OZI-Project/ozi-spec/commit/d0c11a5e473d92c84b9f4574d997cfeeab78cb84))


### Chores


* chore: update publish permissions — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`8ecc572`](https://github.com/OZI-Project/ozi-spec/commit/8ecc572e22f17c33d19c37cca7011a215d39caa8))

* chore: run lint — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`9ec74ea`](https://github.com/OZI-Project/ozi-spec/commit/9ec74eae1822669711e6f201bbc1831f804d0fd4))

* chore: update dev.yml to include freethreaded build — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`71370d1`](https://github.com/OZI-Project/ozi-spec/commit/71370d137caf56efdb069c6fcb02296e0822dd5b))

## 0.25.0 (2025-04-03)


### Build system


* build: add spec support for 3.14 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`393f831`](https://github.com/OZI-Project/ozi-spec/commit/393f831cc7968b1d895cb1eee501dd6424abcdd3))

* build(deps): bump OZI-Project/checkpoint from 1.6.0 to 1.7.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.6.0 to 1.7.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/175eae79f299d6dbad474024b5f791368bd5de85...bec3d96cd1cb3bbce358fbeabc70eb25482bd3bf)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.7.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`b00fd19`](https://github.com/OZI-Project/ozi-spec/commit/b00fd19aebcc4a0c31370297137d80289639b6e9))

* build(deps): bump OZI-Project/publish from 1.13.0 to 1.13.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.0 to 1.13.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/dedb3175dc5d4bb29bcee5a7b659ad7f42c5c68c...26f38aa55610d51537ae92c1e89464a18959ba90)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`5967709`](https://github.com/OZI-Project/ozi-spec/commit/5967709b59a7033a282bdc9788e95329badc1e80))

* build(deps): bump OZI-Project/draft from 1.13.0 to 1.13.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.13.0 to 1.13.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/917b6a5d9a39df52cbdc3a15565c58dfb9b38a10...ed08d630ad83cfd14061b78cf695c20eb51984a5)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.13.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`601b432`](https://github.com/OZI-Project/ozi-spec/commit/601b4322062886bf7415f2bc1d16b920e82bc81c))

* build(deps): bump OZI-Project/release from 1.4.0 to 1.5.0

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.4.0 to 1.5.0.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/bfb9d90fbd2af52d511a9e08306d1b787b8dcfca...924761bcd1ad9c77bbc34363118b2cee4334b8a5)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.5.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`4940a63`](https://github.com/OZI-Project/ozi-spec/commit/4940a63dc80dd7c8153af2ff49f61f59aa3ea9c4))

* build(deps): bump actions/dependency-review-action from 4.5.0 to 4.6.0

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.5.0 to 4.6.0.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/3b139cfc5fae8b618d3eae3675e383bb1769c019...ce3cf9537a52e8119d91fd484ab5b8a807627bf8)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`9117cdc`](https://github.com/OZI-Project/ozi-spec/commit/9117cdc7bb052d2fb28aeac0a607027996446485))

* build(deps): bump actions/upload-artifact from 4.6.1 to 4.6.2

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.6.1 to 4.6.2.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/4cec3d8aa04e39d1a68397de0c4cd6fb9dce8ec1...ea165f8d65b6e75b540449e92b4886f43607fa02)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`1033422`](https://github.com/OZI-Project/ozi-spec/commit/103342292756c5edbe7b497b16f49e9ce785f0a4))

* build(deps): bump step-security/harden-runner from 2.11.0 to 2.11.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.11.0 to 2.11.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/4d991eb9b905ef189e4c376166672c3f2f230481...c6295a65d1254861815972266d5933fd6e532bdf)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`12a68a7`](https://github.com/OZI-Project/ozi-spec/commit/12a68a718528454525289e41efaa81ad916fc0f6))

* build(deps): update ozi-build[core,uv] requirement


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-version: 1.13.0
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`34142cc`](https://github.com/OZI-Project/ozi-spec/commit/34142cc0feea48b98cfd931d6b31dca002e34e68))


### Chores


* chore: Update meson.build for OZI.build 1.13 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`e5341b2`](https://github.com/OZI-Project/ozi-spec/commit/e5341b21c63af7d8173b5062bfffa1f13fbc286e))

## 0.24.0 (2025-03-20)

## 0.23.0 (2025-02-19)


### Bug fixes


* fix: copyright_head and summary regex patterns are now valid regexes — rjdbcm <rjdbcm@outlook.com>
([`ae949b3`](https://github.com/OZI-Project/ozi-spec/commit/ae949b3e6f7f727bfc1b1d303cefa7b990ee9c17))


### Build system


* build(deps): bump OZI-Project/release from 1.3.3 to 1.4.0

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.3.3 to 1.4.0.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/ef531325086db519edaf13b95362051f41bb4802...bfb9d90fbd2af52d511a9e08306d1b787b8dcfca)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`af2ede5`](https://github.com/OZI-Project/ozi-spec/commit/af2ede56644bf5252694f226bcafd2a223e04d54))

* build(deps): bump OZI-Project/draft from 1.12.0 to 1.13.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.12.0 to 1.13.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/cbedf57c7d2529c093518f0652cf4f7324cb3755...917b6a5d9a39df52cbdc3a15565c58dfb9b38a10)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`0d7bdf7`](https://github.com/OZI-Project/ozi-spec/commit/0d7bdf70a38d89229c5cd42d9fc2c85acf6f9b3f))

* build(deps): bump github/codeql-action from 3.28.11 to 3.28.12

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.11 to 3.28.12.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/6bb031afdd8eb862ea3fc1848194185e076637e5...5f8171a638ada777af81d42b55959a643bb29017)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`3837030`](https://github.com/OZI-Project/ozi-spec/commit/38370306cd3a6c219f6a9587d5ea5ab7a216698f))

* build(deps): bump OZI-Project/checkpoint from 1.5.5 to 1.6.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.5.5 to 1.6.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/f14cac563125e34d106b3a1e0ddb2773062953e5...175eae79f299d6dbad474024b5f791368bd5de85)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`381e8de`](https://github.com/OZI-Project/ozi-spec/commit/381e8ded50678c5e6d25585d0bbd1c6e8ac0fa09))

* build(deps): bump OZI-Project/publish from 1.12.0 to 1.13.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.12.0 to 1.13.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/63a52d7e0f5abc79d3fd3f7ecfa7f26efd1c8c69...dedb3175dc5d4bb29bcee5a7b659ad7f42c5c68c)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`0ee4176`](https://github.com/OZI-Project/ozi-spec/commit/0ee41766a3b1b60cc461c463dd25262a5730b69a))

* build(deps): bump ossf/scorecard-action from 2.4.0 to 2.4.1

Bumps [ossf/scorecard-action](https://github.com/ossf/scorecard-action) from 2.4.0 to 2.4.1.
- [Release notes](https://github.com/ossf/scorecard-action/releases)
- [Changelog](https://github.com/ossf/scorecard-action/blob/main/RELEASE.md)
- [Commits](https://github.com/ossf/scorecard-action/compare/62b2cac7ed8198b15735ed49ab1e5cf35480ba46...f49aabe0b5af0936a0987cfb85d86b75731b0186)


updated-dependencies:
- dependency-name: ossf/scorecard-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`fc22a8f`](https://github.com/OZI-Project/ozi-spec/commit/fc22a8f53cb4bb3d986003c4ae1300b1cc5cb8f6))

* build(deps): bump actions/upload-artifact from 4.6.0 to 4.6.1

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.6.0 to 4.6.1.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/65c4c4a1ddee5b72f698fdd19549f0f0fb45cf08...4cec3d8aa04e39d1a68397de0c4cd6fb9dce8ec1)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`c2d31cc`](https://github.com/OZI-Project/ozi-spec/commit/c2d31ccdda5d55523d37532f2eb5a51ac9f58263))

* build(deps): bump github/codeql-action from 3.28.9 to 3.28.11

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.9 to 3.28.11.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/9e8d0789d4a0fa9ceb6b1738f7e269594bdd67f0...6bb031afdd8eb862ea3fc1848194185e076637e5)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`5ca530e`](https://github.com/OZI-Project/ozi-spec/commit/5ca530e391b08d7ec89246a75e50322ae9357b48))

* build(deps): OZI-Project/publish 1.12.0 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`9370e8b`](https://github.com/OZI-Project/ozi-spec/commit/9370e8bdeb81f91336223e352271e9ff5eb69e74))

* build(deps): OZI-Project/draft 1.12.0 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`bd6e336`](https://github.com/OZI-Project/ozi-spec/commit/bd6e33625ecc6b93ff16c343de308df78262a528))

* build(deps): OZI.build[core,uv]~=1.12.0 — rjdbcm <rjdbcm@outlook.com>
([`e85cb95`](https://github.com/OZI-Project/ozi-spec/commit/e85cb954e15a5a500ce0c37e7c750e90a8d31e8d))

* build: use conventional commit parsing — rjdbcm <rjdbcm@outlook.com>
([`c9c4f44`](https://github.com/OZI-Project/ozi-spec/commit/c9c4f44c4bdff0565a43d2577866050395a648d0))


### Chores


* chore: clean up stubs — rjdbcm <rjdbcm@outlook.com>
([`e91ddfa`](https://github.com/OZI-Project/ozi-spec/commit/e91ddfa7e961cc7ab395990ac5b5a22ec7ff1f8e))


### Features


* feat: switch to coventional commit parsing for semantic-release 9.20+ — rjdbcm <rjdbcm@outlook.com>
([`235eb5a`](https://github.com/OZI-Project/ozi-spec/commit/235eb5a9a0015433f00e6ce22080b8bb80c77ed5))

* feat: spec.python.pkg.license.exceptions type now ``dict[str, tuple[str, ...]]`` — rjdbcm <rjdbcm@outlook.com>
([`1524b5e`](https://github.com/OZI-Project/ozi-spec/commit/1524b5ef6c0921d4beb63651a3b06a0884e71363))

* feat: ``Home-page`` removed from spec.python.pkg.info.required — rjdbcm <rjdbcm@outlook.com>
([`ed571eb`](https://github.com/OZI-Project/ozi-spec/commit/ed571eb4791f5b3186fc312e1cf8d7b2a2446041))


### Performance improvements


* perf: spdx_version 3.26.0 — rjdbcm <rjdbcm@outlook.com>
([`2b6a219`](https://github.com/OZI-Project/ozi-spec/commit/2b6a219ba1836e169b59f9ea7c9503b7762f0d3a))

## 0.22.4 (2025-02-14)

## 0.22.3 (2025-02-12)


### Bug fixes


* fix: fill in missing license disambiguation targets

Also makes SPDX_LICENSE_EXCEPTIONS a mapping without changing the current metadata schema. — rjdbcm <rjdbcm@outlook.com>
([`8efc053`](https://github.com/OZI-Project/ozi-spec/commit/8efc053d67931022711752ee9171c58fcd9a5829))

* fix: license map tuple value — rjdbcm <rjdbcm@outlook.com>
([`18a43d5`](https://github.com/OZI-Project/ozi-spec/commit/18a43d5ccd21b2d2eae44b9b7c651ad0f11b0427))


### Build system


* build(deps): bump step-security/harden-runner from 2.10.4 to 2.11.0

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.10.4 to 2.11.0.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/cb605e52c26070c328afc4562f0b4ada7618a84e...4d991eb9b905ef189e4c376166672c3f2f230481)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`36bdaba`](https://github.com/OZI-Project/ozi-spec/commit/36bdabac29406d60c35b11bef17d5c795ff516d8))

## 0.22.2 (2025-02-12)


### Bug fixes


* fix: missing OSI Approved :: CMU License (MIT-CMU) — rjdbcm <rjdbcm@outlook.com>
([`f34f6c0`](https://github.com/OZI-Project/ozi-spec/commit/f34f6c0300d0455eabae1e1b8fa62061aa8dce5b))

## 0.22.1 (2025-02-12)


### Build system


* build(deps): bump OZI-Project/publish from 1.10.0 to 1.10.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.10.0 to 1.10.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/c409525ed951ad88365aefffdb117c7a762a7f3b...9d10868569d8cf25647f221a223d27cfe545ffb2)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`00756d4`](https://github.com/OZI-Project/ozi-spec/commit/00756d4ba339f9c48a7c3097256a9eabd523246f))

* build(deps): bump OZI-Project/draft from 1.11.0 to 1.11.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.11.0 to 1.11.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/93ae8d5e9fd8092aa54474ecaeac12c964260599...d593fa1d1df726466bd156d239ed36986d1c2ab9)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`d3d892b`](https://github.com/OZI-Project/ozi-spec/commit/d3d892b1aca6fb21fb2d6d9226b7148a4a9de396))

## 0.22.0 (2025-02-12)


### Bug fixes


* fix: missing MIT license refs — rjdbcm <rjdbcm@outlook.com>
([`0ff6c10`](https://github.com/OZI-Project/ozi-spec/commit/0ff6c10c6cdb87aa86792537f1fb99cc1ed5fc25))

* fix: update license map to match trove-classifiers~=2025.1 — rjdbcm <rjdbcm@outlook.com>
([`0d9fa0f`](https://github.com/OZI-Project/ozi-spec/commit/0d9fa0f7c1a438c879deb10fd8f90dd26bd5fa27))


### Build system


* build(deps): bump OZI-Project/draft from 1.10.1 to 1.11.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.10.1 to 1.11.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/d3c4167df5ea92adf74006a4406ae85bbf8926e5...93ae8d5e9fd8092aa54474ecaeac12c964260599)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`f1d8563`](https://github.com/OZI-Project/ozi-spec/commit/f1d8563ebb207c939ec2a5f60237334edd695d67))

* build(deps): bump OZI-Project/publish from 1.9.3 to 1.10.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.9.3 to 1.10.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/c35059a13b64575387092e163fa91c2a9f5019da...c409525ed951ad88365aefffdb117c7a762a7f3b)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`ac7dd13`](https://github.com/OZI-Project/ozi-spec/commit/ac7dd1378c16ba70ee4e683b1febb980cb7308c6))

* build(deps): bump github/codeql-action from 3.28.8 to 3.28.9

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.8 to 3.28.9.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/dd746615b3b9d728a6a37ca2045b68ca76d4841a...9e8d0789d4a0fa9ceb6b1738f7e269594bdd67f0)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`8d32027`](https://github.com/OZI-Project/ozi-spec/commit/8d320276072191821e68cad8740a29a8e8fd4561))

* build(deps): update ozi-build[core,uv] requirement


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`665d710`](https://github.com/OZI-Project/ozi-spec/commit/665d710b602b651c91cdf0a42a9712d290d3a5f3))

* build(deps): bump github/codeql-action from 3.28.6 to 3.28.8

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.6 to 3.28.8.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/17a820bf2e43b47be2c72b39cc905417bc1ab6d0...dd746615b3b9d728a6a37ca2045b68ca76d4841a)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e3ffd1d`](https://github.com/OZI-Project/ozi-spec/commit/e3ffd1ddeb1e8c64b3ef5b528f4368412814f604))

* build(deps): bump ossf/scorecard-action from 2.3.3 to 2.4.0

Bumps [ossf/scorecard-action](https://github.com/ossf/scorecard-action) from 2.3.3 to 2.4.0.
- [Release notes](https://github.com/ossf/scorecard-action/releases)
- [Changelog](https://github.com/ossf/scorecard-action/blob/main/RELEASE.md)
- [Commits](https://github.com/ossf/scorecard-action/compare/dc50aa9510b46c811795eb24b2f1ba02a914e534...62b2cac7ed8198b15735ed49ab1e5cf35480ba46)


updated-dependencies:
- dependency-name: ossf/scorecard-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`1d46168`](https://github.com/OZI-Project/ozi-spec/commit/1d461683ccf0b973fa5c7898c6dd952ccab2ae36))

* build: [StepSecurity] Apply security best practices — StepSecurity Bot <bot@stepsecurity.io>
([`962bd63`](https://github.com/OZI-Project/ozi-spec/commit/962bd63a356a0fae5d091fac06cf1bcc8339af71))


### Unknown


* Delete .github/workflows/purge-artifacts.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`f18cc63`](https://github.com/OZI-Project/ozi-spec/commit/f18cc63ebe3482bbf5539965b27ef2142e9d07ec))

## 0.21.1 (2025-01-29)


### Build system


* build(deps): bump OZI-Project/checkpoint from 1.5.4 to 1.5.5

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.5.4 to 1.5.5.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.5.4...1.5.5)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f9f3714`](https://github.com/OZI-Project/ozi-spec/commit/f9f3714d04efa9969c5dcf9daab189c39c6be6f2))

* build(deps): bump OZI-Project/release from 1.3.1 to 1.3.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.3.1 to 1.3.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1.3.1...1.3.3)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f4bb562`](https://github.com/OZI-Project/ozi-spec/commit/f4bb562b86b8023f1976c362628ae9ab7cffb777))

* build(deps): bump OZI-Project/publish from 1.9.0 to 1.9.3

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.9.0 to 1.9.3.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.9.0...1.9.3)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`502eb1b`](https://github.com/OZI-Project/ozi-spec/commit/502eb1b8bfd8546e042bea6d989e12972887a701))

* build(deps): bump OZI-Project/draft from 1.10.0 to 1.10.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.10.0 to 1.10.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.10.0...1.10.1)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`459e613`](https://github.com/OZI-Project/ozi-spec/commit/459e613586ba5b462cf0a881450f4621427bf3fc))

## 0.21.0 (2025-01-28)

## 0.20.2 (2025-01-27)


### Build system


* build(deps): bump OZI-Project/publish from 1.8.0 to 1.9.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.8.0 to 1.9.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.8.0...1.9.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`1f276f9`](https://github.com/OZI-Project/ozi-spec/commit/1f276f9e55e9551be6d7760b3b5606fdeb2191c5))

* build(deps): bump OZI-Project/draft from 1.9.0 to 1.10.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.9.0 to 1.10.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.9.0...1.10.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`c6289d1`](https://github.com/OZI-Project/ozi-spec/commit/c6289d1a4c5c2dbfe35c5a382776f246eddfe864))

## 0.20.1 (2025-01-26)


### Build system


* build(deps): bump pypa/gh-action-pypi-publish from 1.12.3 to 1.12.4

Bumps [pypa/gh-action-pypi-publish](https://github.com/pypa/gh-action-pypi-publish) from 1.12.3 to 1.12.4.
- [Release notes](https://github.com/pypa/gh-action-pypi-publish/releases)
- [Commits](https://github.com/pypa/gh-action-pypi-publish/compare/67339c736fd9354cd4f8cb0b744f2b82a74b5c70...76f52bc884231f62b9a034ebfe128415bbaabdfc)


updated-dependencies:
- dependency-name: pypa/gh-action-pypi-publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`8ff34fb`](https://github.com/OZI-Project/ozi-spec/commit/8ff34fb7a012661ad41bf78ca287e8a8c0fab049))

* build(deps): bump step-security/harden-runner from 2.10.3 to 2.10.4

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.10.3 to 2.10.4.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/c95a14d0e5bab51a9f56296a4eb0e416910cd350...cb605e52c26070c328afc4562f0b4ada7618a84e)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`698a8d0`](https://github.com/OZI-Project/ozi-spec/commit/698a8d00f42e6f09f7714a670373a86ac5432c90))

* build: update release endpoints to support cibuildwheel — rjdbcm <rjdbcm@outlook.com>
([`242103f`](https://github.com/OZI-Project/ozi-spec/commit/242103f5c91663cf03a0d07bc7d65807c0f5850d))

## 0.20.0 (2025-01-15)


### Build system


* build(deps): bump OZI-Project/checkpoint from 1.5.3 to 1.5.4

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.5.3 to 1.5.4.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.5.3...1.5.4)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ac3db6a`](https://github.com/OZI-Project/ozi-spec/commit/ac3db6abeca81346ead221c9a3bd879dac28c419))

* build(deps): bump OZI-Project/draft from 1.8.0 to 1.9.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.8.0 to 1.9.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.8.0...1.9.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`1848b8a`](https://github.com/OZI-Project/ozi-spec/commit/1848b8adc0a29b9a6c210df2d1e484a60bdf0a55))

* build(deps): bump OZI-Project/publish from 1.7.3 to 1.8.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.7.3 to 1.8.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.7.3...1.8.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`0e4d2a5`](https://github.com/OZI-Project/ozi-spec/commit/0e4d2a597a4319660382a8d6462d1ab825196c11))

## 0.19.0 (2025-01-13)

## 0.18.2 (2025-01-09)


### Build system


* build(deps): bump OZI-Project/release from 1.2.1 to 1.3.1

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.2.1 to 1.3.1.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1.2.1...1.3.1)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`09c1b3e`](https://github.com/OZI-Project/ozi-spec/commit/09c1b3e5a08c3c784a64c8421fe6efbe4d3f2c99))

* build(deps): bump step-security/harden-runner from 2.10.2 to 2.10.3

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.10.2 to 2.10.3.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/0080882f6c36860b6ba35c610c98ce87d4e2f26f...c95a14d0e5bab51a9f56296a4eb0e416910cd350)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ecc749b`](https://github.com/OZI-Project/ozi-spec/commit/ecc749be2dde0e89f25d34521f3e3b5f6d6d3bd5))

* build(deps): bump OZI-Project/checkpoint from 1.5.1 to 1.5.3

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.5.1 to 1.5.3.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.5.1...1.5.3)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`677be40`](https://github.com/OZI-Project/ozi-spec/commit/677be40f7ca8355f78fae5b8bb9ee160741a3652))

## 0.18.1 (2025-01-05)


### Build system


* build(deps): bump OZI-Project/draft from 1.7.0 to 1.8.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.7.0 to 1.8.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.7.0...1.8.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`015290e`](https://github.com/OZI-Project/ozi-spec/commit/015290e9484ce451dbe52f552528c49e4a0cb52f))

* build(deps): bump OZI-Project/publish from 1.7.2 to 1.7.3

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.7.2 to 1.7.3.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.7.2...1.7.3)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`6b28e95`](https://github.com/OZI-Project/ozi-spec/commit/6b28e9554cfa3ec74bf8f0c6daf27f8fe47c91a5))

* build(deps): bump OZI-Project/release from 1.1.2 to 1.2.1

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.1.2 to 1.2.1.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1.1.2...1.2.1)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`e4c1b2f`](https://github.com/OZI-Project/ozi-spec/commit/e4c1b2f621df539b2a52801a9ea12c09b1dd5d7a))

* build(deps): bump OZI-Project/checkpoint from 1.4.0 to 1.5.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.4.0 to 1.5.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.4.0...1.5.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`c02dd9a`](https://github.com/OZI-Project/ozi-spec/commit/c02dd9a7dcf4bfcd58a9c78fafa832000402432a))


### Unknown


* Update dependabot.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`bcc91c2`](https://github.com/OZI-Project/ozi-spec/commit/bcc91c246ca0e2c75a222d7091eaf519a8331de4))

## 0.18.0 (2025-01-01)

## 0.17.1 (2024-12-30)

## 0.17.0 (2024-12-30)


### Bug fixes


* fix: ci module missing from build — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`9115a15`](https://github.com/OZI-Project/ozi-spec/commit/9115a1540ad9db9ad27471f2680831cf0bc343bd))

* fix: remove duplicate license data — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`6a49f7a`](https://github.com/OZI-Project/ozi-spec/commit/6a49f7a5769be287241d3d891c52a1eb7bdf4adf))


### Build system


* build(deps): update ozi-build[core,uv] requirement


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`8688a4c`](https://github.com/OZI-Project/ozi-spec/commit/8688a4c31584b90eb26f39564f0100f18d22eec4))

* build: use pyproject build version in API — rjdbcm <rjdbcm@outlook.com>
([`88f5c39`](https://github.com/OZI-Project/ozi-spec/commit/88f5c398151f4a630842d17daacc5578e352fa38))

* build(deps): update ozi-build[core,uv] requirement


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`2386aa2`](https://github.com/OZI-Project/ozi-spec/commit/2386aa2b8403cd229637c06112ad89f7a564bf7f))


### Features


* feat: OZI.build 1.10 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`a6fed56`](https://github.com/OZI-Project/ozi-spec/commit/a6fed563ebb1afde3d9831a2b1d7a38aa68e8d93))

## 0.16.0 (2024-12-19)


### Features


* feat: move provider specific CI config into its own key — rjdbcm <rjdbcm@outlook.com>
([`37cb363`](https://github.com/OZI-Project/ozi-spec/commit/37cb363010a169e687522b34484ddf3bba8a8fc2))

## 0.15.4 (2024-12-19)


### Build system


* build(deps): bump OZI-Project/publish from 1.7.1 to 1.7.2

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.7.1 to 1.7.2.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.7.1...1.7.2)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`1437e97`](https://github.com/OZI-Project/ozi-spec/commit/1437e972501680c7e807239041104bd0662978c3))

* build(deps): bump OZI-Project/draft from 1.6.3 to 1.7.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.6.3 to 1.7.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.6.3...1.7.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`753312c`](https://github.com/OZI-Project/ozi-spec/commit/753312c33ce4d56eafd2683535e6d0114e84ee40))


### Unknown


* Officially support Python 3.13 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`6e64153`](https://github.com/OZI-Project/ozi-spec/commit/6e64153d0171cbfcf08308a403632c33e2ee45e2))

* Create purge-artifacts.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`561c762`](https://github.com/OZI-Project/ozi-spec/commit/561c7622066dc153861317f0e30dd883411818e9))

## 0.15.3 (2024-12-17)


### Build system


* build(deps): bump OZI-Project/publish from 1.7.0 to 1.7.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.7.0 to 1.7.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.7.0...1.7.1)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`945dbbe`](https://github.com/OZI-Project/ozi-spec/commit/945dbbe4c53f7b807017353d05c710d7b1202c69))

* build(deps): bump OZI-Project/draft from 1.6.2 to 1.6.3

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.6.2 to 1.6.3.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.6.2...1.6.3)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`cb2fc76`](https://github.com/OZI-Project/ozi-spec/commit/cb2fc76fef586a5dc91b4f9d1008f11e27469e7f))

* build(deps): bump OZI-Project/draft from 1.6.1 to 1.6.2

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.6.1 to 1.6.2.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.6.1...1.6.2)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`fc9cd28`](https://github.com/OZI-Project/ozi-spec/commit/fc9cd28818f69b72f28bd0967b7c7f2cd9207c04))

## 0.15.2 (2024-12-16)


### Build system


* build(deps): bump OZI-Project/draft from 1.6.0 to 1.6.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.6.0 to 1.6.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.6.0...1.6.1)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`cc028fe`](https://github.com/OZI-Project/ozi-spec/commit/cc028fe76900e110c321b594b3e99c8d1a229045))

## 0.15.1 (2024-12-16)


### Bug fixes


* fix: add pkg-containers.githubusercontent.com:443 to publish endpoints — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`11c3ade`](https://github.com/OZI-Project/ozi-spec/commit/11c3adee3113d1d4b3a2f7b82735f1612cbeea51))


### Build system


* build(deps): bump OZI-Project/release from 1.1.1 to 1.1.2

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.1.1 to 1.1.2.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1.1.1...1.1.2)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`df32964`](https://github.com/OZI-Project/ozi-spec/commit/df329642de097c812d31854df7148dfdcaf83af0))

* build(deps): bump OZI-Project/checkpoint from 1.3.0 to 1.4.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.3.0 to 1.4.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.3.0...1.4.0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`29a4a69`](https://github.com/OZI-Project/ozi-spec/commit/29a4a6903e9a9596bddd81d0ffc469965a7118db))

* build(deps): bump OZI-Project/release from 1.1.0 to 1.1.1

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.1.0 to 1.1.1.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1.1.0...1.1.1)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`c556432`](https://github.com/OZI-Project/ozi-spec/commit/c5564329890fcad66700ac455a25232f54fe8ea2))

* build(deps): bump OZI-Project/publish from 1.6.0 to 1.7.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.6.0 to 1.7.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.6.0...1.7.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`23bc5b8`](https://github.com/OZI-Project/ozi-spec/commit/23bc5b852009599c56777d7583c2f5467a35ac7f))

* build(deps): bump OZI-Project/release from 1.0.5 to 1.1.0

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.5 to 1.1.0.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1.0.5...1.1.0)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`e069286`](https://github.com/OZI-Project/ozi-spec/commit/e069286cbc0f55efdf1164679050498d78f17f54))

* build(deps): bump OZI-Project/checkpoint from 1.2.1 to 1.3.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.2.1 to 1.3.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.2.1...1.3.0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`8289373`](https://github.com/OZI-Project/ozi-spec/commit/828937334878c6f511c64f9c1ae49ccb497da5e6))


### Unknown


* Update ozi.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`5cfe14e`](https://github.com/OZI-Project/ozi-spec/commit/5cfe14e5ce3fe7fc61ed0e6f0991b1ef53ebb91a))

* Update dev.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`5dceddf`](https://github.com/OZI-Project/ozi-spec/commit/5dceddf7b0628afcc36d200e4d542c342d749c38))

* Update dev.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`5813c88`](https://github.com/OZI-Project/ozi-spec/commit/5813c882a085145fe4422c2758c534779f8a28d1))

## 0.15.0 (2024-12-16)


### Bug fixes


* fix: add ghcr endpoint
([`1535c2d`](https://github.com/OZI-Project/ozi-spec/commit/1535c2d82614b77ae1011258eced46d882d6a706))

* fix: run isort — rjdbcm <rjdbcm@outlook.com>
([`4b977ff`](https://github.com/OZI-Project/ozi-spec/commit/4b977ff0593d0b7cc59890bc116ee27cc5d6f7fd))

* fix: script name typo — rjdbcm <rjdbcm@outlook.com>
([`7883351`](https://github.com/OZI-Project/ozi-spec/commit/78833511e1632ebcfb665c6728db8bb93a9660af))

* fix: add pypi-publish version getter script — rjdbcm <rjdbcm@outlook.com>
([`61f15e9`](https://github.com/OZI-Project/ozi-spec/commit/61f15e92e7ed9c48ac9f1f4f5cadfbda05f1f1e8))


### Build system


* build(deps): bump OZI-Project/checkpoint from 1.2.1 to 1.3.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.2.1 to 1.3.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.2.1...1.3.0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`10874dd`](https://github.com/OZI-Project/ozi-spec/commit/10874dd06387c8973c66ad23d62024b14a60afb8))


### Features


* feat: add checkpoint workflows and separate gh-action-pypi-publish metadata — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`091ac8b`](https://github.com/OZI-Project/ozi-spec/commit/091ac8bbbb3db3594b635606ca513bfd742e3623))


### Performance improvements


* perf: add pipx to ci backend requirements — rjdbcm <rjdbcm@outlook.com>
([`caa7aae`](https://github.com/OZI-Project/ozi-spec/commit/caa7aaebd49271cf73065e2c72a574a6beb17721))

* perf: add gh_action_pypi_publish key to ci for compatibility with gh-action-pypi-publish>1.12.x — rjdbcm <rjdbcm@outlook.com>
([`bba2664`](https://github.com/OZI-Project/ozi-spec/commit/bba26646fdf06121526b6eac56be1504bf8596f3))


### Unknown


* Create dev.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`6b2edf8`](https://github.com/OZI-Project/ozi-spec/commit/6b2edf865428bfad3c4649083de523ec70c255e9))

* Update ozi.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`68ef656`](https://github.com/OZI-Project/ozi-spec/commit/68ef656681b831acf48c63bfead95ad173458417))

## 0.14.1 (2024-12-10)

## 0.14.0 (2024-12-09)


### Build system


* build(deps): bump OZI-Project/publish from 1.6.0 to 1.6.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.6.0 to 1.6.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.6.0...1.6.1)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`fb018b0`](https://github.com/OZI-Project/ozi-spec/commit/fb018b059bbaa30fcea75ed1c7367a4432696bb1))

* build(deps): update ozi-build[core,uv] requirement

Updates the requirements on [ozi-build[core,uv]](https://github.com/OZI-Project/OZI.build) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/OZI.build/releases)
- [Commits](https://github.com/OZI-Project/OZI.build/compare/1.7.2...1.8.0)


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`2042c6b`](https://github.com/OZI-Project/ozi-spec/commit/2042c6bc4ae8ba754e82f4aa774da0a6fac9149e))

* build(deps): bump OZI-Project/draft from 1.5.0 to 1.6.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.5.0 to 1.6.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.5.0...1.6.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`34a0356`](https://github.com/OZI-Project/ozi-spec/commit/34a0356722c74759ba9af08cf2c319857ab8e55a))

* build(deps): bump OZI-Project/publish from 1.5.0 to 1.6.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.5.0 to 1.6.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.5.0...1.6.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`f189b19`](https://github.com/OZI-Project/ozi-spec/commit/f189b19ab9810690b3aecf86c3478c1954ad26fb))


### Performance improvements


* perf: OZI.build~=1.8.0 in ``ci.py`` — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`2209653`](https://github.com/OZI-Project/ozi-spec/commit/2209653bd3d270064d4df072a739894112e2f54e))

## 0.13.1 (2024-12-06)


### Performance improvements


* perf: OZI.build~=1.7.2 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`c3658fc`](https://github.com/OZI-Project/ozi-spec/commit/c3658fc00802c7c3f964800fc66d99680ddf1767))


### Unknown


* Update pyproject.toml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`c26965c`](https://github.com/OZI-Project/ozi-spec/commit/c26965c7db7452cce5c1f7d4446647704cdf2c88))

* Update dependabot.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`28b6486`](https://github.com/OZI-Project/ozi-spec/commit/28b64864809351d08e5273954c93feed80448e44))

## 0.13.0 (2024-11-30)


### Features


* feat: bump to workaround CI issues — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`e8862ca`](https://github.com/OZI-Project/ozi-spec/commit/e8862ca24287b23d3e8dcac191d7c71ed42f7488))


### Unknown


* Update ozi.wrap — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`8729fc2`](https://github.com/OZI-Project/ozi-spec/commit/8729fc2567d65eebf324f557faccdc0f2a2c7257))

## 0.12.3 (2024-11-28)


### Build system


* build(ozi.wrap): OZI 1.25 subproject — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`aad551a`](https://github.com/OZI-Project/ozi-spec/commit/aad551abbb8a05e278bfdcfdf65565ba8865d9b5))

* build: update license metadata — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`f11aa58`](https://github.com/OZI-Project/ozi-spec/commit/f11aa589d80700fed2389d6dc26a610126d16fa3))

* build: update license to MIT-0 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`4c1c8c1`](https://github.com/OZI-Project/ozi-spec/commit/4c1c8c14450c5e01fd8ae982011cd3155df10cb0))

## 0.12.2 (2024-11-20)


### Build system


* build: allow build patch tag — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`a943072`](https://github.com/OZI-Project/ozi-spec/commit/a943072e3f09f6616dc1c59f10c5128301ce69ba))

* build(deps): bump step-security/harden-runner from 2.10.1 to 2.10.2

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.10.1 to 2.10.2.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/91182cccc01eb5e619899d80e4e971d6181294a7...0080882f6c36860b6ba35c610c98ce87d4e2f26f)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`48d7243`](https://github.com/OZI-Project/ozi-spec/commit/48d72433f714df7f910541d3bbec4af7047336d1))

## 0.12.1 (2024-11-18)


### Bug fixes


* fix: typing of default value getter — rjdbcm <rjdbcm@outlook.com>
([`9b8ad40`](https://github.com/OZI-Project/ozi-spec/commit/9b8ad4041cb109205fe90ed70babdbbbdd640b0b))


### Performance improvements


* perf: add harden_runner version info to metadata — rjdbcm <rjdbcm@outlook.com>
([`7d77b7d`](https://github.com/OZI-Project/ozi-spec/commit/7d77b7d6e432552c998502e20bfcdce368393527))


### Unknown


* run black — rjdbcm <rjdbcm@outlook.com>
([`39a5288`](https://github.com/OZI-Project/ozi-spec/commit/39a5288545ed05acf49fa0abfd3d2e53e8b48123))

## 0.12.0 (2024-11-15)


### Bug fixes


* fix: comment out nested dependencies incompatible with dependabot — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`1436e82`](https://github.com/OZI-Project/ozi-spec/commit/1436e82fdbb93dc6fb0bf7d91f13bdb56fcd7d9e))


### Build system


* build(deps): bump OZI-Project/draft from 1.4.1 to 1.5.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.4.1 to 1.5.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.4.1...1.5.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`742bccf`](https://github.com/OZI-Project/ozi-spec/commit/742bccf26a4f66651e33a0360167d4b7e1bcb3e8))

* build(deps): bump OZI-Project/release from 1.0.4 to 1.0.5

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.4 to 1.0.5.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1.0.4...1.0.5)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9367667`](https://github.com/OZI-Project/ozi-spec/commit/9367667155f16a91996053c52865d17f471e7a16))

* build(deps): bump OZI-Project/publish from 1.4.1 to 1.5.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.4.1 to 1.5.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.4.1...1.5.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`b28f25f`](https://github.com/OZI-Project/ozi-spec/commit/b28f25f1daa8f7d3f850107a08a6f00170a3baf7))


### Features


* feat: python-semantic-release~=9.14.0 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`533aa27`](https://github.com/OZI-Project/ozi-spec/commit/533aa27a9db840b70b7b63e0c6974eba8a91c2c0))


### Performance improvements


* perf: OZI 1.24  — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`9cd3fc8`](https://github.com/OZI-Project/ozi-spec/commit/9cd3fc86c6837bcbf1f8435fcca1f31004e06d89))


### Unknown


* Update dependabot.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`1afb475`](https://github.com/OZI-Project/ozi-spec/commit/1afb4750d118b99ae0991a0e33ddcc82d5d27841))

## 0.11.7 (2024-11-14)


### Performance improvements


* perf: add provenance key to ci — rjdbcm <rjdbcm@outlook.com>
([`a669e0e`](https://github.com/OZI-Project/ozi-spec/commit/a669e0edb36bce5229d445c537abbfef64eceed1))

## 0.11.6 (2024-11-14)


### Build system


* build(deps): bump OZI-Project/checkpoint from 1.1.1 to 1.2.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.1.1 to 1.2.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.1.1...1.2.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`876aeed`](https://github.com/OZI-Project/ozi-spec/commit/876aeed60bec1c28eaa162b9a2a7f327cf4b4d39))

* build(deps): bump OZI-Project/draft from 1.4.0 to 1.4.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.4.0 to 1.4.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.4.0...1.4.1)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f634155`](https://github.com/OZI-Project/ozi-spec/commit/f634155c25ee0d95e78fbb5103a1dd655aaff2cd))


### Performance improvements


* perf: always use the same workflow versions as build — rjdbcm <rjdbcm@outlook.com>
([`8692e01`](https://github.com/OZI-Project/ozi-spec/commit/8692e018ea2933048b861a927e4ece248bb38562))

## 0.11.5 (2024-11-06)


### Bug fixes


* fix: pin OZI-Project/publish to 1.4.1 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`8a01455`](https://github.com/OZI-Project/ozi-spec/commit/8a01455597abde3a4fa729504f36923b6d9998a4))


### Build system


* build(deps): bump OZI-Project/publish from 1.4.0 to 1.4.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.4.0 to 1.4.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.4.0...1.4.1)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f9c42b2`](https://github.com/OZI-Project/ozi-spec/commit/f9c42b2f9dc0e9e07bfde1d38fedc894ec9a1345))


### Unknown


* :lock: update publish workflow endpoints — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`acab398`](https://github.com/OZI-Project/ozi-spec/commit/acab398e8c6544a16c6bbffc813b966899364496))

## 0.11.4 (2024-10-28)


### Bug fixes


* fix: add coverage deferall — rjdbcm <rjdbcm@outlook.com>
([`fc1ff36`](https://github.com/OZI-Project/ozi-spec/commit/fc1ff36e9e869290053255d1a4c187703ace939a))

* fix: Liskov substition violation — rjdbcm <rjdbcm@outlook.com>
([`03ee532`](https://github.com/OZI-Project/ozi-spec/commit/03ee532cb7646be7e17e95d29a0e60d8633e40ad))

* fix: use int to calculate ozi version from spec — rjdbcm <rjdbcm@outlook.com>
([`c48b18d`](https://github.com/OZI-Project/ozi-spec/commit/c48b18d6d33876a545d200f64a4c49164bebe9af))

## 0.11.3 (2024-10-28)


### Bug fixes


* fix: run black — rjdbcm <rjdbcm@outlook.com>
([`e7cae93`](https://github.com/OZI-Project/ozi-spec/commit/e7cae93c4a7c52f03c5ca908ac465c444492e36c))

* fix: remove hardcoded version string, OZI version now a set interval ahead of ozi-spec version — rjdbcm <rjdbcm@outlook.com>
([`d304976`](https://github.com/OZI-Project/ozi-spec/commit/d304976a24c0df92c7f49aa4890a152abaccc7c7))

## 0.11.2 (2024-10-28)


### Bug fixes


* fix: update spec target version to 1.24 — rjdbcm <rjdbcm@outlook.com>
([`e22297d`](https://github.com/OZI-Project/ozi-spec/commit/e22297d2441d173f1b3348ad4e5769f3d977b1f6))


### Build system


* build(deps): bump OZI-Project/checkpoint from 1.0.2 to 1.1.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.0.2 to 1.1.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.0.2...1.1.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`667f0b1`](https://github.com/OZI-Project/ozi-spec/commit/667f0b191e42db2e817628608cf1d2409d0e7b22))

## 0.11.1 (2024-10-25)


### Bug fixes


* fix: OZI-Project/checkpoint 1.1.1

only build wheel if cibuildwheel passes — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`4cbd408`](https://github.com/OZI-Project/ozi-spec/commit/4cbd408afb280371f43b417bee6fafd864dac05c))

## 0.11.0 (2024-10-25)


### Features


* feat: OZI-Project/checkpoint 1.1.0 - build is checkpointed as well — rjdbcm <rjdbcm@outlook.com>
([`4b69eee`](https://github.com/OZI-Project/ozi-spec/commit/4b69eee05015be1d11ccf8b3df6033685e82c9b6))

## 0.10.9 (2024-10-23)


### Performance improvements


* perf: refactor types and remove undocumented requirement on typing_extensions for Python < 3.11 — rjdbcm <rjdbcm@outlook.com>
([`eb247d6`](https://github.com/OZI-Project/ozi-spec/commit/eb247d69a84b9c2911a7fc21bb685ffa8285b766))

## 0.10.8 (2024-10-18)


### Build system


* build(deps): bump OZI-Project/draft from 1.3.0 to 1.4.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.3.0 to 1.4.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.3.0...1.4.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`e4551a9`](https://github.com/OZI-Project/ozi-spec/commit/e4551a92f989d139a2afd0040ec5cb0610bc763f))

* build(deps): bump OZI-Project/publish from 1.3.0 to 1.4.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.3.0 to 1.4.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.3.0...1.4.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`f51b896`](https://github.com/OZI-Project/ozi-spec/commit/f51b8962216d9d6c9f9d186fc7d055e60cd044d6))

* build(deps): bump OZI-Project/publish from 1.2.2 to 1.3.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.2.2 to 1.3.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.2.2...1.3.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`b73d3dc`](https://github.com/OZI-Project/ozi-spec/commit/b73d3dc64ab7f1f9a9db3fbc33389e66ee9c83d0))

* build(deps): bump OZI-Project/draft from 1.2.2 to 1.3.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.2.2 to 1.3.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.2.2...1.3.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`2a2c76d`](https://github.com/OZI-Project/ozi-spec/commit/2a2c76ddec43e93ca5dbb22c66165a63c4872250))


### Performance improvements


* perf(semantic-release): update draft and publish to 1.4.0

semantic-release 9.12 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`8c86e97`](https://github.com/OZI-Project/ozi-spec/commit/8c86e97b44be1a4c7fd189562b099b5e7b856927))

## 0.10.7 (2024-10-14)


### Bug fixes


* fix: bump OZI version to 1.23 — rjdbcm <rjdbcm@outlook.com>
([`24b3055`](https://github.com/OZI-Project/ozi-spec/commit/24b3055b73f8af6d3dafdb84bb3b23a707e5023d))

## 0.10.6 (2024-10-14)


### Bug fixes


* fix: stubfile typo — rjdbcm <rjdbcm@outlook.com>
([`f4d0952`](https://github.com/OZI-Project/ozi-spec/commit/f4d09523e062c448a26d2327ed661a87bbc41651))

## 0.10.5 (2024-10-14)


### Bug fixes


* fix: missing py.typed — rjdbcm <rjdbcm@outlook.com>
([`d179e58`](https://github.com/OZI-Project/ozi-spec/commit/d179e58efb33c7755efb98ba80c3e74a71e5e8c3))

## 0.10.4 (2024-10-14)


### Build system


* build(deps): bump OZI-Project/release from 1.0.3 to 1.0.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.3 to 1.0.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1.0.3...1.0.4)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`dac7049`](https://github.com/OZI-Project/ozi-spec/commit/dac7049f05290ce1b391ad3d22c67cdf455aaa09))

* build(deps): bump OZI-Project/checkpoint from 1.0.1 to 1.0.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.0.1 to 1.0.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.0.1...1.0.2)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ad7e8bb`](https://github.com/OZI-Project/ozi-spec/commit/ad7e8bbf1720e793062f55627a6473ecc0a85680))

* build(deps): bump OZI-Project/draft from 1.1.0 to 1.2.2

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.1.0 to 1.2.2.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.1.0...1.2.2)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`c6cc3cb`](https://github.com/OZI-Project/ozi-spec/commit/c6cc3cb56e3d9eba5c938327c05db9268e7a9486))

* build(deps): bump OZI-Project/publish from 1.1.0 to 1.2.2

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.1.0 to 1.2.2.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.1.0...1.2.2)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`d1f806c`](https://github.com/OZI-Project/ozi-spec/commit/d1f806cc5fcc0a81dea7218296cd59f804a3fd48))


### Performance improvements


* perf: publish and draft 1.2.2, checkpoint 1.0.2, release 1.0.4 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`8f3a1b4`](https://github.com/OZI-Project/ozi-spec/commit/8f3a1b4da5b1ad5f4aee6ea7c96dcaa23e830a8f))

## 0.10.3 (2024-10-14)


### Build system


* build: increase lint timeout — rjdbcm <rjdbcm@outlook.com>
([`7b5de9e`](https://github.com/OZI-Project/ozi-spec/commit/7b5de9e4037b95ebb745283c1a7eb3a3f15c5c00))


### Performance improvements


* perf: add typing stubfiles — rjdbcm <rjdbcm@outlook.com>
([`2feefa5`](https://github.com/OZI-Project/ozi-spec/commit/2feefa55a57944b8360141ba6b2a7dd494ab3bd1))

## 0.10.2 (2024-10-08)


### Bug fixes


* fix: skip flaky 3.13 checkpoint for now — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`30cae94`](https://github.com/OZI-Project/ozi-spec/commit/30cae94cdab98cb2d4f987ea11e4727898d81902))

* fix: add no cover — rjdbcm <rjdbcm@outlook.com>
([`b16adcc`](https://github.com/OZI-Project/ozi-spec/commit/b16adccc9677ae59443208b220be491844da66a3))

* fix: set default loop scope for async tests — rjdbcm <rjdbcm@outlook.com>
([`4263f39`](https://github.com/OZI-Project/ozi-spec/commit/4263f3947efaeef8de5deca63bab43be76e3e62a))


### Build system


* build: double the timeout for lint suite — rjdbcm <rjdbcm@outlook.com>
([`6b084a7`](https://github.com/OZI-Project/ozi-spec/commit/6b084a7a9ad90748c09919478cbc09aa8470c698))

* build(deps): bump OZI-Project/publish from 1.0.1 to 1.1.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.0.1 to 1.1.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.0.1...1.1.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`a2c8d4a`](https://github.com/OZI-Project/ozi-spec/commit/a2c8d4ac76bbb4145bc1c60e93482d3143e22227))

* build(deps): bump OZI-Project/draft from 1.0.1 to 1.1.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.0.1 to 1.1.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.0.1...1.1.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`f9f3931`](https://github.com/OZI-Project/ozi-spec/commit/f9f3931265f547e9e97268e53652bcdc57a163be))

* build(deps): bump OZI-Project/release from 1.0.1 to 1.0.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.1 to 1.0.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1.0.1...1.0.3)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e40bb18`](https://github.com/OZI-Project/ozi-spec/commit/e40bb183eaac8ad091d70f4762ed09d40f2246c4))


### Performance improvements


* perf: deprecate Python 3.10 checkpoint — rjdbcm <rjdbcm@outlook.com>
([`9704e07`](https://github.com/OZI-Project/ozi-spec/commit/9704e07b5f8ff0b55d1d83b276e5784969612c0f))

* perf: release and draft v1.1 - semantic-release 9.9 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`37bb25f`](https://github.com/OZI-Project/ozi-spec/commit/37bb25f95de43a4463cfd7e904a9a4b08091df96))

## 0.10.1 (2024-09-27)


### Build system


* build(deps): bump OZI-Project/publish from 1.0.0 to 1.0.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.0.0 to 1.0.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.0.0...1.0.1)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e5d05cf`](https://github.com/OZI-Project/ozi-spec/commit/e5d05cf7ba1d7cf66a25642ead9af3ea909960d5))

* build(deps): bump OZI-Project/release from 1.0.0 to 1.0.1

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.0 to 1.0.1.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1.0.0...1.0.1)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`d3bdd18`](https://github.com/OZI-Project/ozi-spec/commit/d3bdd18d6fa6e7cf33bbdf8c3b09283faba7bcc4))

* build(deps): bump OZI-Project/draft from 1.0.0 to 1.0.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.0.0 to 1.0.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.0.0...1.0.1)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`27355f4`](https://github.com/OZI-Project/ozi-spec/commit/27355f4679ee0eaa2130971eb3b5d81bb4a06b48))

* build(deps): bump OZI-Project/checkpoint from 1.0.0 to 1.0.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.0.0 to 1.0.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.0.0...1.0.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`8c22a9d`](https://github.com/OZI-Project/ozi-spec/commit/8c22a9dceecf66602b7becef1c9fa703323f07be))

* build(deps): bump OZI-Project/publish from 1.0.0 to 1.0.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.0.0 to 1.0.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.0.0...1.0.1)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`7bb2796`](https://github.com/OZI-Project/ozi-spec/commit/7bb27960bd0bfe22742114f0ed24df57d47f6980))

* build(deps): bump OZI-Project/release from 1.0.0 to 1.0.1

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.0 to 1.0.1.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1.0.0...1.0.1)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`7bb2796`](https://github.com/OZI-Project/ozi-spec/commit/7bb27960bd0bfe22742114f0ed24df57d47f6980))

* build(deps): bump OZI-Project/draft from 1.0.0 to 1.0.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.0.0 to 1.0.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.0.0...1.0.1)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`7bb2796`](https://github.com/OZI-Project/ozi-spec/commit/7bb27960bd0bfe22742114f0ed24df57d47f6980))

* build(deps): bump OZI-Project/checkpoint from 1.0.0 to 1.0.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.0.0 to 1.0.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.0.0...1.0.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`7bb2796`](https://github.com/OZI-Project/ozi-spec/commit/7bb27960bd0bfe22742114f0ed24df57d47f6980))


### Performance improvements


* perf: pin all github CI workflows to 1.0.0 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`76d32e5`](https://github.com/OZI-Project/ozi-spec/commit/76d32e5c401ccdd4b15f8ea603abd23aa78139b0))

* perf: pin all github CI workflows to 1.0.1 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>

 — dependabot[bot] <support@github.com>
Signed-off-by: Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
Co-authored-by: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>
([`7bb2796`](https://github.com/OZI-Project/ozi-spec/commit/7bb27960bd0bfe22742114f0ed24df57d47f6980))


### Unknown


* Release (#82)
([`7bb2796`](https://github.com/OZI-Project/ozi-spec/commit/7bb27960bd0bfe22742114f0ed24df57d47f6980))

## 0.10.0 (2024-09-16)

## 0.9.5 (2024-09-10)

## 0.9.4 (2024-09-06)


### Bug fixes


* fix: add RUF200 to tool.ruff.lint ignores — rjdbcm <rjdbcm@outlook.com>
([`4a648e3`](https://github.com/OZI-Project/ozi-spec/commit/4a648e3c3660c9e0063bc85cca3d0aa608968d69))

* fix: draft@0.3.11 and release@0.8.11 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`9d81f33`](https://github.com/OZI-Project/ozi-spec/commit/9d81f33f232997ffb914a05dd52a0f80ecdf2c24))


### Build system


* build(deps): bump step-security/harden-runner from 2.9.1 to 2.10.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.9.1 to 2.10.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/5c7944e73c4c2a096b17a9cb74d65b6c2bbafbde...91182cccc01eb5e619899d80e4e971d6181294a7)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`892e9ea`](https://github.com/OZI-Project/ozi-spec/commit/892e9eab007fe6fbf486f0b52903348564045a4e))

* build(deps): bump OZI-Project/release from 0.8.11 to 1.0.0

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.11 to 1.0.0.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.8.11...1.0.0)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`8fa5549`](https://github.com/OZI-Project/ozi-spec/commit/8fa5549d68d91feb6b028139b4bb2015ae5ac4cb))

* build(deps): bump OZI-Project/publish from 0.1.11 to 1.0.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.11 to 1.0.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.11...1.0.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`6232a10`](https://github.com/OZI-Project/ozi-spec/commit/6232a1057ba0eb2eb9ec5d59004d20f6e6487b51))

* build(deps): bump OZI-Project/draft from 0.3.11 to 1.0.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.11 to 1.0.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.11...1.0.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`3e19eda`](https://github.com/OZI-Project/ozi-spec/commit/3e19eda33d3bb0c3143dd322cddebcc7151dc3a3))

* build(deps): bump OZI-Project/checkpoint from 0.5.2 to 1.0.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.2 to 1.0.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.5.2...1.0.0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`a0cb42b`](https://github.com/OZI-Project/ozi-spec/commit/a0cb42b98d6030e3966d132a487eb6527e19e620))

* build(deps): bump OZI-Project/draft from 0.3.10 to 0.3.11

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.10 to 0.3.11.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.10...0.3.11)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`4295af1`](https://github.com/OZI-Project/ozi-spec/commit/4295af1d55822cbacd0def7759c9d0e9c43e834b))

* build(deps): bump OZI-Project/release from 0.8.10 to 0.8.11

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.10 to 0.8.11.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.8.10...0.8.11)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`4061f90`](https://github.com/OZI-Project/ozi-spec/commit/4061f9066bdb3f59108a66a887ff75bf7a09cfba))

* build(deps): bump OZI-Project/draft from 0.3.9 to 0.3.10

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.9 to 0.3.10.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.9...0.3.10)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e0b459f`](https://github.com/OZI-Project/ozi-spec/commit/e0b459f68771d57b70c9c160e49d526029d8b4b2))

* build(deps): bump OZI-Project/publish from 0.1.10 to 0.1.11

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.10 to 0.1.11.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.10...0.1.11)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`abed060`](https://github.com/OZI-Project/ozi-spec/commit/abed060ff01055797baf5f50edaac0606aca2a0e))


### Features


* feat: move cibuildwheel and twine to utility apps — rjdbcm <rjdbcm@outlook.com>
([`e33e5ec`](https://github.com/OZI-Project/ozi-spec/commit/e33e5ecb0ceb9f08c513a0d83e225a5346f9778d))


### Performance improvements


* perf: Python 3.13 support — rjdbcm <rjdbcm@outlook.com>
([`efb9c24`](https://github.com/OZI-Project/ozi-spec/commit/efb9c2447a33e5346f91387399914327b748bc31))

* perf: pin all github CI workflows to 1.0.0 — rjdbcm <rjdbcm@outlook.com>
([`c66e60a`](https://github.com/OZI-Project/ozi-spec/commit/c66e60ae88c726b24bdddeb27f209a1a7c6d345f))

* perf: OZI-Project/draft@0.3.10 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`2638fe5`](https://github.com/OZI-Project/ozi-spec/commit/2638fe52f47bf60a12f23bfdc5e06d73fa05d537))

* perf: OZI-Project/publish@0.1.11 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`10d88fe`](https://github.com/OZI-Project/ozi-spec/commit/10d88fe77084d5fc4034f1c82ddf67f73e179df1))


### Unknown


* Update dependabot.yml — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`6cc96b0`](https://github.com/OZI-Project/ozi-spec/commit/6cc96b03afee014b9a87d1fa9d2b1416e3d97b50))

## 0.9.3 (2024-09-02)


### Build system


* build(deps): OZI.build~=1.5 — rjdbcm <rjdbcm@outlook.com>
([`29f7da6`](https://github.com/OZI-Project/ozi-spec/commit/29f7da69efc5685e2ff22250f0fd0cf241b45c36))

## 0.9.2 (2024-08-30)


### Bug fixes


* fix(pkg.py): remove requirements.in and add .gitignore — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`3f856f9`](https://github.com/OZI-Project/ozi-spec/commit/3f856f9ceb7631c95ba4330fe5ee785e9efb6250))

## 0.9.1 (2024-08-28)


### Bug fixes


* fix: correct key typo — rjdbcm <rjdbcm@outlook.com>
([`0805bac`](https://github.com/OZI-Project/ozi-spec/commit/0805bacc3f17c982acc362aee1ce8734f6b04339))

* fix: project-url to project-urls list — rjdbcm <rjdbcm@outlook.com>
([`5871986`](https://github.com/OZI-Project/ozi-spec/commit/58719861cb8cf5f2f27bf35a9d7ced44ffe42c88))

* fix: update pyproject.toml for OZI 1.20 — rjdbcm <rjdbcm@outlook.com>
([`881b79a`](https://github.com/OZI-Project/ozi-spec/commit/881b79aa722ba215c60a559cf23cb9886a878d90))


### Performance improvements


* perf: OZI.build[core]~=1.4.3 — rjdbcm <rjdbcm@outlook.com>
([`ed66155`](https://github.com/OZI-Project/ozi-spec/commit/ed66155c592a98b28a31e38de4e7218d2414039e))

## 0.9.0 (2024-08-27)


### Features


* feat: remove requirements.in target OZI.build 1.3 — rjdbcm <rjdbcm@outlook.com>
([`7cf50c3`](https://github.com/OZI-Project/ozi-spec/commit/7cf50c36db9266c65a83e7f19d4f93e7e92e732d))

## 0.8.1 (2024-08-23)


### Bug fixes


* fix: pin spec to 0.8 and OZI to 1.19 — rjdbcm <rjdbcm@outlook.com>
([`54718a3`](https://github.com/OZI-Project/ozi-spec/commit/54718a326cffd2e8494d9dea6fc6ae6e91cdc9d2))

## 0.8.0 (2024-08-23)

## 0.7.0 (2024-08-22)


### Build system


* build(deps): bump OZI-Project/publish from 0.1.9 to 0.1.10

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.9 to 0.1.10.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.9...0.1.10)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`82eec52`](https://github.com/OZI-Project/ozi-spec/commit/82eec52f2529583143254b00b602c1d82fe7ef4d))

* build(deps): bump OZI-Project/checkpoint from 0.5.1 to 0.5.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.1 to 0.5.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.5.1...0.5.2)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`c4926bc`](https://github.com/OZI-Project/ozi-spec/commit/c4926bc1b82a5217c9f0e56fdd5e868962b0e2ed))

* build(deps): bump OZI-Project/draft from 0.3.8 to 0.3.9

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.8 to 0.3.9.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.8...0.3.9)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`1b46763`](https://github.com/OZI-Project/ozi-spec/commit/1b46763411561d769d696ec9fe819c750ccadc92))

* build(deps): bump OZI-Project/release from 0.8.9 to 0.8.10

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.9 to 0.8.10.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.8.9...0.8.10)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9a18441`](https://github.com/OZI-Project/ozi-spec/commit/9a1844126123239242f7a4af5aab989025ecf02b))


### Features


* feat: OZI.build renders optional_dependencies — rjdbcm <rjdbcm@outlook.com>
([`f8f5088`](https://github.com/OZI-Project/ozi-spec/commit/f8f50889523cd26362001821d77dbe94df9692f1))

* feat: add invoke to build-system deps

also patches github workflows — rjdbcm <rjdbcm@outlook.com>
([`fa7e9cf`](https://github.com/OZI-Project/ozi-spec/commit/fa7e9cfbaa34d5562d4d1be24f5f12774fc735da))

## 0.6.1 (2024-08-16)


### Unknown


* :pencil2: OZI 1.18 and spec 0.6 pin versions — rjdbcm <rjdbcm@outlook.com>
([`7992390`](https://github.com/OZI-Project/ozi-spec/commit/79923901da0352a028ffcc010904ed2185caf3f0))

## 0.6.0 (2024-08-16)


### Features


* feat: added ``cibuildwheel`` and ``twine`` as plugins

Also pins pip-tools~=7.4, OZI.build~=1.0.2, tox~=4.18, tox-gh~=1.3 — rjdbcm <rjdbcm@outlook.com>
([`02062f1`](https://github.com/OZI-Project/ozi-spec/commit/02062f1fbf2a8d1750bab9e3855152eeb7d118e6))


### Unknown


* :rotating_light: run black — rjdbcm <rjdbcm@outlook.com>
([`abf9aa2`](https://github.com/OZI-Project/ozi-spec/commit/abf9aa2902c8a77b032a9aa3457226942599f5ec))

## 0.5.10 (2024-08-12)


### Build system


* build(deps): bump OZI-Project/release from 0.7.4 to 0.8.9

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.7.4 to 0.8.9.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.7.4...0.8.9)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`268f056`](https://github.com/OZI-Project/ozi-spec/commit/268f0564ec46b9e561a8358b480cc3d42f003b1c))

* build(deps): bump OZI-Project/release from 0.7.3 to 0.7.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.7.3 to 0.7.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.7.3...0.7.4)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`cc6207c`](https://github.com/OZI-Project/ozi-spec/commit/cc6207cc12c76bbec4f3f3e18041dd36456d089e))

* build(deps): bump OZI-Project/checkpoint from 0.5.0 to 0.5.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.0 to 0.5.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.5.0...0.5.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`7263fec`](https://github.com/OZI-Project/ozi-spec/commit/7263fec1eea67c623fa65c798e0f8e1b1b2df2f3))

* build(deps): bump OZI-Project/draft from 0.3.7 to 0.3.8

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.7 to 0.3.8.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.7...0.3.8)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`821e408`](https://github.com/OZI-Project/ozi-spec/commit/821e4084616885747547bcf332a7adad26f0cd1e))

* build(deps): bump step-security/harden-runner from 2.9.0 to 2.9.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.9.0 to 2.9.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/0d381219ddf674d61a7572ddd19d7941e271515c...5c7944e73c4c2a096b17a9cb74d65b6c2bbafbde)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`4886f1f`](https://github.com/OZI-Project/ozi-spec/commit/4886f1f45ba30e4c61906322c5673bbf7413a25e))


### Performance improvements


* perf(ci.py): Release version=0.8.9 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`8d7e85c`](https://github.com/OZI-Project/ozi-spec/commit/8d7e85c67c83c7b6ee92e1b6a166d7785b8b7d6e))

## 0.5.9 (2024-08-05)


### Performance improvements


* perf: Bump OZI-Project/draft from 0.3.7 to 0.3.8 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`b4422c2`](https://github.com/OZI-Project/ozi-spec/commit/b4422c232cd3e91bc829d17475418d93bab5ac71))

* perf: Bump OZI-Project/release from 0.7.3 to 0.7.4 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`b97460b`](https://github.com/OZI-Project/ozi-spec/commit/b97460b613a7d397b160cf4430b55b17b18a45d9))

* perf: Bump OZI-Project/checkpoint from 0.5.0 to 0.5.1 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`b2369f7`](https://github.com/OZI-Project/ozi-spec/commit/b2369f7bdeae8881de0b73a0b8bf86e7dc74b120))

## 0.5.8 (2024-07-29)


### Performance improvements


* perf: draft 0.3.7 — rjdbcm <rjdbcm@outlook.com>
([`9356eec`](https://github.com/OZI-Project/ozi-spec/commit/9356eecbfd41c2c59f0eb821051e5c0c871293f4))

* perf: publish 0.1.9 — rjdbcm <rjdbcm@outlook.com>
([`c5fbfcb`](https://github.com/OZI-Project/ozi-spec/commit/c5fbfcb46b50f8212c28ecb5d2def521179e45a9))

## 0.5.7 (2024-07-25)


### Bug fixes


* fix: OZI default version 1.17 — rjdbcm <rjdbcm@outlook.com>
([`018880d`](https://github.com/OZI-Project/ozi-spec/commit/018880de8601b6930aef6a26d0e59f8a772700e6))


### Build system


* build(deps): bump OZI-Project/publish from 0.1.8 to 0.1.9

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.8 to 0.1.9.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.8...0.1.9)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`6ad4dff`](https://github.com/OZI-Project/ozi-spec/commit/6ad4dff4be252202a93f012b009ed43a4f324086))

* build(deps): bump OZI-Project/draft from 0.3.6 to 0.3.7

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.6 to 0.3.7.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.6...0.3.7)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`731cd8e`](https://github.com/OZI-Project/ozi-spec/commit/731cd8e0fba988578d0017af49140c179262afc2))

## 0.5.6 (2024-07-22)


### Bug fixes


* fix: correct ``templates/templates/*`` names to include ``.j2`` extension
([`cf1094e`](https://github.com/OZI-Project/ozi-spec/commit/cf1094e8e598afdd62e1d90a87415b699e2bf2a5))

## 0.5.5 (2024-07-19)


### Bug fixes


* fix: use sigstore-v3 actions in github CI — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`d45030f`](https://github.com/OZI-Project/ozi-spec/commit/d45030ffefea9496ed296614451e5ea7e15d97cf))

## 0.5.4 (2024-07-18)


### Build system


* build(deps): bump OZI-Project/release from 0.6.5 to 0.7.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.6.5 to 0.7.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.6.5...0.7.3)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`15ac435`](https://github.com/OZI-Project/ozi-spec/commit/15ac4353be38569289103aed8404f3e9bb1601a1))

* build(deps): bump OZI-Project/checkpoint from 0.4.2 to 0.5.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.4.2 to 0.5.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.4.2...0.5.0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`770d374`](https://github.com/OZI-Project/ozi-spec/commit/770d374d80d8690502aa6337846896a62546f197))

* build(deps): bump OZI-Project/draft from 0.3.3 to 0.3.6

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.3 to 0.3.6.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.3...0.3.6)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`219a326`](https://github.com/OZI-Project/ozi-spec/commit/219a326e38ea6d4e63e458e0ff493d4a098d6f50))

* build(deps): bump step-security/harden-runner from 2.8.0 to 2.9.0

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.8.0 to 2.9.0.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/v2.8.0...0d381219ddf674d61a7572ddd19d7941e271515c)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`f98d0e8`](https://github.com/OZI-Project/ozi-spec/commit/f98d0e8a55cfcf6cc30f3363d5ce94ee21ac2290))

* build(deps): bump OZI-Project/publish from 0.1.6 to 0.1.8

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.6 to 0.1.8.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.6...0.1.8)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`751407a`](https://github.com/OZI-Project/ozi-spec/commit/751407ab63ad8a2cdbc133b5e392efe29385974c))


### Unknown


* Update dependabot.yml — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`88c5e71`](https://github.com/OZI-Project/ozi-spec/commit/88c5e716e0e82ea2ac0d98dc6dff312d74dc93b2))

* Create dependabot.yml — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`a5c8af8`](https://github.com/OZI-Project/ozi-spec/commit/a5c8af8b6d8e72f4a57433ef2c1052ffdb296113))

## 0.5.3 (2024-07-18)


### Bug fixes


* fix: OZI.build>=0.0.27 — rjdbcm <rjdbcm@outlook.com>
([`4fd6a01`](https://github.com/OZI-Project/ozi-spec/commit/4fd6a0120d4ccf080d6ec21540874931d4bca0bd))

## 0.5.2 (2024-07-16)


### Performance improvements


* perf: OZI-Project/draft@0.3.5 — rjdbcm <rjdbcm@outlook.com>
([`6344e19`](https://github.com/OZI-Project/ozi-spec/commit/6344e1920ea5e033c062c62bba4a3e7ec70cbcad))

* perf: OZI-Project/checkpoint@0.4.3 — rjdbcm <rjdbcm@outlook.com>
([`37f3cdb`](https://github.com/OZI-Project/ozi-spec/commit/37f3cdba726c2c921762bac49bad2e38aac3353c))

* perf: OZI-Project/release@0.6.6 — rjdbcm <rjdbcm@outlook.com>
([`49a6d93`](https://github.com/OZI-Project/ozi-spec/commit/49a6d939d5e2808c1de1205974c6c90fd8db4b0e))

* perf: OZI-Project/publish@0.1.8 — rjdbcm <rjdbcm@outlook.com>
([`1699c50`](https://github.com/OZI-Project/ozi-spec/commit/1699c5023b492fe2ed49d7340c702abd74f14789))

## 0.5.1 (2024-07-11)


### Bug fixes


* fix: update version — rjdbcm <rjdbcm@outlook.com>
([`158212b`](https://github.com/OZI-Project/ozi-spec/commit/158212baf2061b55a99c556bc0f1862498ba16ac))

## 0.5.0 (2024-07-07)


### Performance improvements


* perf: run black — rjdbcm <rjdbcm@outlook.com>
([`a2f0bc8`](https://github.com/OZI-Project/ozi-spec/commit/a2f0bc8356204624cbbf719f363272ef7531e1ed))

## 0.4.1 (2024-07-01)

## 0.4.0 (2024-07-01)


### Bug fixes


* fix: update commit parser templates — rjdbcm <rjdbcm@outlook.com>
([`4975a1c`](https://github.com/OZI-Project/ozi-spec/commit/4975a1cc3e3e10b38cae41e5584b92649505eb4e))

* fix: individual file license/copyright header corrected to Unlicense
([`74ff29c`](https://github.com/OZI-Project/ozi-spec/commit/74ff29cc0ea4e991cddffd1da6f553eb1fbb40a8))

* fix: doc and download link metadata — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`8c849f6`](https://github.com/OZI-Project/ozi-spec/commit/8c849f692a566ff65499712f38e3b10da86b1dc8))


### Continuous integration


* ci: add 0.x branch pattern — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`5d606c8`](https://github.com/OZI-Project/ozi-spec/commit/5d606c850a9316b1b9f7ecf0cc7c9897b82f6fa1))


### Features


* feat(src.py SrcTemplate): add ``templates``, ``subprojects`` and modified ``ci_provider`` to be a dictionary of tuples — rjdbcm <rjdbcm@outlook.com>
([`6dbd31c`](https://github.com/OZI-Project/ozi-spec/commit/6dbd31c9f0a1053ed0b544c954cc71c20bf150b3))

* feat: tag OZI 1.14
([`b6cb028`](https://github.com/OZI-Project/ozi-spec/commit/b6cb0285901d95512e7545c06edd7f2c539c4125))


### Performance improvements


* perf: OZI-Project/draft@0.3.4 — rjdbcm <rjdbcm@outlook.com>
([`e747e9b`](https://github.com/OZI-Project/ozi-spec/commit/e747e9b1c5caeb5c54c51f66a30eab7b57850878))

* perf: OZI-Project/publish@0.1.7 — rjdbcm <rjdbcm@outlook.com>
([`c224b07`](https://github.com/OZI-Project/ozi-spec/commit/c224b078da4060195d040dec97abb58ca12fb057))


### Unknown


* Update requirements.in — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`a0bcce3`](https://github.com/OZI-Project/ozi-spec/commit/a0bcce34cf6ba9abfd1bdc0685ae9d6c62a7c742))

## 0.3.0 (2024-07-01)


### Features


* feat: init from OZI 1.13.31 spec submodule source
([`434d1db`](https://github.com/OZI-Project/ozi-spec/commit/434d1db4aff6652cd9b88002d18c4d14f55cbd0d))
